srbErrors

Module srbErrors |
[hide private]
[frames] | no frames]

## Source Code for Module srbErrors

       1
       2  errmsgs = {0 : "No Error",
       3  -1 : "No such connection/handle",
       4  -1000 :                 "START_OF_ERR_CODE",
       5  -1001 :                 "NULL or bad userName",
       6  -1002 : "hostBase auth failed",
       7  -1003 :         "MDAS auth failed",
       8  -1004 :                 "auth failed",
       9  -1005 :          "SEA auth failed",
      10  -1006 :          "SEA encryption failed",
      11  -1007 :          "proxy user not privileged",
      12  -1008 : "illegal operation for a ticket user",
      13  -1009 :          "SEA not supported",
      14  -1010 :    "MDAS_AUTH not supported",
      15  -1011 :    "AUTH_ERR_GSI_SETUP",
      16  -1012 :    "AUTH_ERR_GSI_AUTH",
      17  -1013 :    "AUTH_ERR_NO_GSI_SERVER_DN",
      18  -1014 :    "AUTH_ERR_NO_GSI_DN_IN_MCAT",
      19  -1015 :    "AUTH_ERR_GSI_DN_MISMATCH",
      20  -1016 :     "GSI not supported",
      21  -1017 :         "Encrypt auth failed",
      22  -1018 :         "getpwuid error",
      23  -1019 : "SRB Secure Communications not supported",
      24  -1020 : "SRB Secure Communications not established",
      25  -1021 : "SRB Secure Communications Library Error",
      26  -1022 : "The client and the server users are from different zone",
      27  -1023 :       "Problem with a server connecting to a remote SRB master. The remote SRB master may be down",
      28  -1024 :       "Doing a cross-zone operation. Client auth is required",
      29  -1025 :       "cross-zone auth required delegate client auth. This authentication step failed",
      30  -1100 :  "client command failed",
      31  -1101 :  "wrong returned lenghth",
      32  -1102 :  "Invalid user",
      33  -1103 :  "Bad host name",
      34  -1104 :  "Unable to open socket",
      35  -1105 :  "getsockname error",
      36  -1106 :  "PacketSend error",
      37  -1107 :  "recv error",
      38  -1108 :  "socket fdopen error",
      39  -1109 :  "socket connect error",
      40  -1110 :  "The query has no answer",
      41  -1111 :  "Client library malloc error",
      42  -1112 :  "Invalid domain name",
      43  -1113 :  "broken pipe to server",
      44  -1114 :  "FATAL error msg from server",
      45  -1115 :  "The input collection is incorrect",
      46  -1116 :  "The input collection/dataname is too long",
      47  -1117 :  "write error. length returned not same as input",
      48  -1118 :  "client|svr version incompatible",
      49  -1119 :  "The function call is not supported by the server",
      50  -1120 :  "The num of arg does not match the configuration",
      51  -1121 :  "The authentication scheme is not supported",
      52  -1122 :  "The authentication option string is bad",
      53  -1123 :  "env HOME is not set",
      54  -1124 :  "Location of tape resource on different host",
      55  -1125 :  "Problem with the .MdasEnv and/or .MdasAuth files",
      56  -1200 :  "Unable to open .MdasEnv file",
      57  -1201 :  "Unable to open .MdasAuth file",
      58  -1202 :  "No default Resource",
      59  -1203 :  "Unable to open .MdasEnv file",
      60  -1204 :  "Query returns too many rows",
      61  -1205 : "MAX_OPEN_SRBIO_EXCEEDED",
      62  -1206 : "SRB_OBJ_WRITE_ERROR",
      63  -1207 : "SRB_OBJ_READ_ERROR",
      64  -1208 : "SRB_OBJ_SEEK_ERROR",
      65  -1209 : "SRBIO_MEMORY_ALLOCATION_ERROR",
      66  -1210 : "SRBIO_FATAL_ERROR",
      67  -1211 : "SRBIO_FILL_DIRTY_ERROR",
      68  -1212 : "UTIL_ERROR_TARGET_ALREADY_EXIST",
      69  -1300 :  "Unknown UNIX error.",
      70  -1301 :  "UNIX error. Not super-user",
      71  -1302 :  "UNIX error. No such file or directory",
      72  -1303 :  "UNIX error. No such process",
      73  -1304 :  "UNIX error. Interrupted system call",
      74  -1305 :  "UNIX error. I/O error",
      75  -1306 :  "UNIX error. No such device or address",
      76  -1307 :  "UNIX error. Arg list too long",
      77  -1308 :  "UNIX error. Exec format error",
      78  -1309 :  "UNIX error. Bad file number",
      79  -1310 :  "UNIX error. No children",
      80  -1311 :  "UNIX error. Resource temporarily unavailable",
      81  -1312 :  "UNIX error. Not enough core",
      82  -1313 :  "UNIX error. Permission denied",
      83  -1314 :  "UNIX error. Bad address",
      84  -1315 :  "UNIX error. Block device required",
      85  -1316 :  "UNIX error. Mount device busy",
      86  -1317 :  "UNIX error. File exists",
      87  -1318 :  "UNIX error. Cross-device link",
      88  -1319 :  "UNIX error. No such device",
      89  -1320 :  "UNIX error. Not a directory",
      90  -1321 :  "UNIX error. Is a directory",
      91  -1322 :  "UNIX error. Invalid argument",
      92  -1323 :  "UNIX error. File table overflow",
      93  -1324 :  "UNIX error. Too many open files",
      94  -1325 :  "UNIX error. Inappropriate ioctl for device",
      95  -1326 :  "UNIX error. Text file busy",
      96  -1327 :  "UNIX error. File too large",
      97  -1328 :  "UNIX error. No space left on device",
      98  -1329 :  "UNIX error. Illegal seek",
      99  -1330 :  "UNIX error. Read only file system",
     100  -1331 :  "UNIX error. Too many links",
     101  -1332 :  "UNIX error. Broken pipe",
     102  -1333 :  "UNIX error. Math arg out of domain of func",
     103  -1334 :  "UNIX error. Math result not representable",
     104  -1335 :  "UNIX error. No message of desired type",
     105  -1336 :  "UNIX error. Identifier removed",
     106  -1337 :  "UNIX error. Channel number out of range",
     107  -1338 :  "UNIX error. Level 2 not synchronized",
     108  -1339 :  "UNIX error. Level 3 halted",
     109  -1340 :  "UNIX error. Level 3 reset",
     110  -1341 :  "UNIX error. Link number out of range",
     111  -1342 :  "UNIX error. Protocol driver not attached",
     112  -1343 :  "UNIX error. No CSI structure available",
     113  -1344 :  "UNIX error. Level 2 halted",
     114  -1345 :  "UNIX error. Deadlock condition",
     115  -1346 :  "UNIX error. No record locks available",
     116  -1347 :  "UNIX error. Operation canceled",
     117  -1348 :  "UNIX error. Operation not supported",
     118  -1349 :  "UNIX error. Disc quota exceeded",
     119  -1350 :  "UNIX error. Invalid exchange",
     120  -1351 :  "UNIX error. Invalid request descriptor",
     121  -1352 :  "UNIX error. Exchange full",
     122  -1353 :  "UNIX error. No anode",
     123  -1354 :  "UNIX error. Invalid request code",
     124  -1355 :  "UNIX error. Invalid slot",
     125  -1356 :  "UNIX error. File locking deadlock error",
     126  -1400 :  "Unknown HPSS error",
     127  -1401 :  "HPSS error. Operation not permitted",
     128  -1402 :  "HPSS error. No such file or directory",
     129  -1405 :  "HPSS error. I/O error",
     130  -1409 :  "HPSS error. Bad file descriptor",
     131  -1411 :  "HPSS error. Resource temporarily unavailable",
     132  -1412 :  "HPSS error. Not enough space",
     133  -1413 :  "HPSS error. Permission denied",
     134  -1414 :  "HPSS error. Bad address",
     135  -1416 :  "HPSS error. Resource busy ",
     136  -1417 :  "HPSS error. File exists",
     137  -1419 :  "HPSS error. No such device",
     138  -1420 :  "HPSS error. Not a directory",
     139  -1421 :  "HPSS error. Is a directory",
     140  -1422 :  "HPSS error. Invalid argument",
     141  -1424 :  "HPSS error. Too many open files",
     142  -1428 :  "HPSS error. No space left on device",
     143  -1431 :  "HPSS error. Too many links",
     144  -1433 :  "HPSS error. Domain error within math function",
     145  -1434 :  "HPSS error. Result too large",
     146  -1447 :  "HPSS error. Write-protected media",
     147  -1450 :  "HPSS error. No connection",
     148  -1452 :  "HPSS error. No filesystem",
     149  -1459 :  "HPSS error. Message too long",
     150  -1464 :  "HPSS error. Operation not supported on socket",
     151  -1478 :  "HPSS error. Connection timed out",
     152  -1486 :  "HPSS error. File name too long",
     153  -1487 :  "HPSS error. Directory not empty",
     154  -1499 :  "HPSS error. Cannot assign a COS",
     155  -1500 :  "HPSS timeout error. Cannot finish HPSS hpss_Open() operation in the alloted time",
     156  -1501 :  "HPSS timeout error. Cannot finish HPSS hpss_Open() operation in the alloted time",
     157  -1502 :  "HPSS timeout error. Cannot finish HPSS hpssOpen() operation in alloted time",
     158  -1503 :  "HPSS timeout error. Cannot finish HPSS hpssRead hpssCreate() operation in alloted time",
     159  -1504 :  "HPSS timeout error. Cannot finish HPSS hpssStage() operation in alloted time",
     160  -1505 :  "HPSS timeout error. Cannot finish HPSS hpssCreate() operation in alloted time",
     161  -1600 :  "The requested SQL result is too long",
     162  0 : "",
     163  1 : "",
     164  -1700 :  "Bat HTTP path name",
     165  -1800 :  "The file type must be HPSS file type",
     166  -1801 :  "HPSS not enabled for HPSS operations",
     167  -1802 :  "hpss_ReadList error",
     168  -1803 :  "hpss_WriteList error",
     169  -2001 : "",
     170  -2003 : "",
     171  -2006 : "",
     172  -2007 : "",
     173  -2008 :          "Permission Error",
     174  -2100 :  "resource format (hostaddr:port error",
     175  -2101 :  "host addr not in config",
     176  -2102 :  "DB type not supported",
     177  -2103 :  "The input obj/file descriptor is out of range",
     178  -2104 : "illegal filename",
     179  -2105 :  "stat error",
     180  -2106 :  "illegal chkFlag error",
     181  -2107 :   "The service is not supported",
     182  -2108 : "Attempt to unreg file in vault",
     183  -2200 :   "SRB server startup error",
     184  -2201 :   "SRB server descriptor table overflow",
     185  -2202 :  "unable to connect to remote host",
     186  -2203 :   "The service is not supported",
     187  -2204 :   "malloc error",
     188  -2205 :   "host table error",
     189  -2206 :   "Inconsistent return from mdas",
     190  -2207 :  "MCAT server down or data/hostConfig file error",
     191  -2208 :   "MCAT connection is restarted. Not -ive because not an error",
     192  -2209 :  "The file is not in the SRB vault",
     193  -2210 :  "The server has trouble receiving packet from client",
     194  -2211 :  "The server has trouble sending packet to client",
     195  -2212 :  "SYS_ERR_NO_MCAT_HOST",
     196  -2213 :  "PACKM_ERR_PARSE_FORMAT",
     197  -2214 :  "SYS_ERR_NOT_REMOTE_OPR",
     198  -2215 :  "SYS_ERR_PORTAL_CONN",
     199  -2216 :  "SYS_ERR_NULL_INPUT",
     200  -2217 :  "SYS_ERR_PORTAL_COOKIE_SEND",
     201  -2218 :  "SYS_ERR_PTHREAD_CREATE",
     202  -2219 :  "SYS_ERR_TRANSFER_FAILED",
     203  -2220 :  "SYS_IN_MAINTENENCE_MODE",
     204  -2300 :  "Login error",
     205  -2301 :  "mi_exec error",
     206  -2302 :  "mi_get_result error",
     207  -2303 :  "mi_next_row error",
     208  -2304 :  "mi_value error",
     209  -2305 :  "MI_DML error",
     210  -2306 :  "illegal result type",
     211  -2307 :  "more than one row result",
     212  -2308 :  "mi_query_finish error",
     213  -2309 :  "result is not a large object",
     214  -2310 :  "object seek (mi_large_object_seek) error",
     215  -2311 :  "mi_large_object_copy error",
     216  -2312 :  "object descriptor error",
     217  -2313 :  "mi_large_object_create error",
     218  -2314 :  "mi_large_object_open error",
     219  -2400 :  "resource has not been registered",
     220  -2401 :  "No matching resource type",
     221  -2402 :  "No matching open flag",
     222  -2403 :  "No MDAS enabled host",
     223  -2404 :  "Bytes written does no match bytes read",
     224  -2405 :  "No matching in srbObjTypeEntry",
     225  -2406 :  "No. of replica created is less than the request value",
     226  -2407 :  "Illegal Proxy Operation number",
     227  -2408 :  "Illegal object descriptor",
     228  -2409 :  "resource is not a single resource",
     229  -2410 :  "create not allowed with open",
     230  -2411 :  "No matching value for Replicate Condition",
     231  -2412 :  "No Permanent resource in logical resource",
     232  -2413 :  "The input container name does not fit format",
     233  -2414 :  "The input container name has not been registered as a container",
     234  -2415 :  "The cache container does not exist even one has been made",
     235  -2416 :  "The operation is out of the offset/size bound for the inContainer object",
     236  -2417 :  "The max container size has been exceeded",
     237  -2418 :  "Internal error. Inconsistent container size",
     238  -2419 :  "The resource does not support container",
     239  -2420 :  "The container has not resource",
     240  -2421 :  "The replication operation for the inContainer object not allowed",
     241  -2422 :  "The move operation for the inContainer object not allowed",
     242  -2423 :  "Cannot open a Container object idirectly",
     243  -2424 :  "server socket error",
     244  -2425 :  "illegal proxy command path name",
     245  -2426 :  "SFO Class not supported",
     246  -2427 :  "SFO client buffer overflow",
     247  -2428 :  "Unlinking container not allowed",
     248  -2429 : "Server Object Buffer Overflow when Reading",
     249  -2430 :  "The input path is not a full path name",
     250  -2431 :  "The stat input is bad",
     251  -2432 :  "Attempt to open a collection",
     252  -2433 :  "Attempt to perform a collection operation on a non-collection",
     253  -2434 :  "Unable to open lockfile",
     254  -2435 :  "Unable to open lock lockfile",
     255  -2436 :  "Illegal Lock Cmd",
     256  -2437 :  "The number of copies is less that requested",
     257  -2438 :  "SRB objects and/or containers are not from the same MCAT",
     258  -2439 :  "Parallel Put - A thread timed out waiting thread 0 create call",
     259  -2440 :  "OBJ_ERR_BAD_CHKSUM",
     260  -2441 :  "OBJ_ERR_RM_LAST_AUTH_SCHEME",
     261  -2500 :  "flags for open must be O_RDONLY or O_WRONLY",
     262  -2501 :  "Wrong returned value",
     263  -2502 :  "fileName too long",
     264  -2503 :  "Response timeout",
     265  -2504 :  "Not connected to an FTP Server",
     266  -2505 :  "command length error",
     267  -2700 :  "ORA Login and password  error",
     268  -2701 :  "ORA oracle_exec error",
     269  -2702 :  "ORA memory map not deleted error",
     270  -2703 :  "ORA memory map not created error",
     271  -2705 :  "ORA result is not an oracle large object",
     272  -2706 :  "ORA object seek error",
     273  -2707 :   "ORA large object create error",
     274  -2708 :  "ORA object descriptor error",
     275  -2709 :  "ORA large objectopen error",
     276  -2710 :  "ORA No memory available for exfd",
     277  -2711 :  "ORA bad data pathname for sql stmt",
     278  -2712 :  "ORA large object could not be closed",
     279  -2713 :  "ORA cursor for the query could not be created",
     280  -2714 :  "ORA error parsing the sql stmt",
     281  -2715 :  "ORA error fetching the data from the sql select results",
     282  -2716 :  "ORA error performing piecewise insert",
     283  -2718 :  "ORA error binding the oracle",
     284  -2719 :  "ORA error binding variable for piecewise fetch of long datatype",
     285  -2720 :   "ORA error - a null ptr srb lobj",
     286  -2721 : "DB_TAB_OPEN_ENV_ERROR",
     287  -2722 : "DB_TAB_CONNECT_ERROR",
     288  -2723 : "INP_ERR_FORMAT",
     289  -2724 : "DB_TAB_DISCONNECT_ERROR",
     290  -2725 : "DB_TAB_CLOSE_ENV_ERROR",
     291  -2726 : "TABLE_SID_GENERAL_ERROR",
     292  -2727 : "LOGICAL_EXPRESSION_EVALUATION_ERROR",
     293  -2728 : "DB_TAB_READ_ERROR",
     294  -2729 : "DB_TAB_WRITE_ERROR",
     295  -2730 : "EXPRESSION_SYNTAX_ERROR",
     296  -2731 : "DATA_TAG_ERROR",
     297  -2732 : "RE_EVALUATION_ERROR",
     298  -2733 : "RE_MATCH_NOT_FOUND",
     299  -2734 : "SRB_OBJ_OPEN_ERROR",
     300  -2735 : "INPUT_PROPERTY_ERROR",
     301  -2736 : "TEMPLATE_FUNCTION_NOT_FOUND",
     302  -2737 : "FUNCTION_CALL_PARAM_ERROR",
     303  -2738 :  "DB No memory available",
     304  -2739 : "MISSING_DATA_ERROR",
     305  -2740 : "CACHE_REQUEST_FAILED",
     306  -2741 : "SYB_CTX_MEMORY_ALLOCATION_ERROR",
     307  -2742 : "SYB_CT_INIT_ERROR",
     308  -2743 : "SYB_ERROR_CALLBACK_INIT_ERROR",
     309  -2744 : "SYB_CONNECT_MEMORY_ALLOCATION_ERROR",
     310  -2745 : "SYB_INITIATE_COMMAND_ERROR",
     311  -2746 : "SYB_SEND_COMMAND_ERROR",
     312  -2747 : "SYB_COMMAND_RESULTS_ERROR",
     313  -2748 : "SYB_COMMAND_RESULT_TYPE_ERROR",
     314  -2749 : "SYB_RES_INFO_ERROR",
     315  -2750 : "SYB_NUM_RESULT_ERROR",
     316  -2751 : "SYB_SELECT_DESCRIBE_ERROR",
     317  -2752 : "SYB_DATA_MEMORY_ALLOCATION_ERROR",
     318  -2753 : "SYB_COMMAND_MEMORY_ALLOCATION_ERROR",
     319  -2754 : "MODIFY_QUERY_LIST_ERROR",
     320  -2755 : "GET_QUERY_LIST_ERROR",
     321  -2756 : "FUNCTION_NOT_SUPPORTED",
     322  -2757 : "BAD_QUERY_INFO_FORNAT",
     323  -2758 : "BAD_QUERY_INFO_FORNAT",
     324  -2759 : "USER_IN_GROUP_ALREADY_IN_CAT",
     325  -2760 : "USER_AUTH_SCHEME_ALREADY_IN_CAT",
     326  -2761 : "MIME_EXT_ALREADY_IN_CAT",
     327  -2762 : "MDAS_AT_DATA_TYP_EXT_INSERTION_ERROR",
     328  -2763 : "ACCESS_ID_ALREADY_IN_CAT",
     329  -2764 : "ACCESS_CONSTRAINT_ALREADY_IN_CAT",
     330  -2765 : "INFO_ALREADY_IN_CAT",
     331  -2766 : "GENERIC_INSERTION_ERROR",
     332  -2767 : "USER_TYP_NAME_NOT_FOUND",
     333  -2768 : "METADATA_ALREADY_IN_CAT",
     334  -2769 : "USER_AUTH_SCHEME_NOT_FOUND",
     335  -2770 : "SERVER_LOCATION_NOT_FOUND",
     336  -2771 : "SERVER_NETPREFIX_NOT_FOUND",
     337  -2772 : "USER_NAME_NOT_FOUND",
     338  -2773 : "DOMAIN_DESC_NOT_FOUND",
     339  -2774 : "ZONE_NAME_NOT_FOUND",
     340  -2775 : "PARENT_SERVER_LOCATION_NOT_FOUND",
     341  -2776 : "RSRC_TYP_NAME_NOT_FOUND",
     342  -2777 : "RSRC_ACCESS_LIST_NOT_FOUND",
     343  -2778 : "RSRC_ACCESS_PRIVILEGE_NOT_FOUND",
     344  -2779 : "RSRC_ACCESS_CONSTRAINT_NOT_FOUND",
     345  -2780 : "RSRC_ACCESS_ID_NOT_FOUND",
     346  -2781 : "DATA_TYP_NAME_NOT_FOUND",
     347  -2782 : "DATA_TYPE_MIME_STRING_NOT_FOUND",
     348  -2783 : "DATA_TYPE_EXTENDERS_NOT_FOUND",
     349  -2784 : "PARENT_DATA_TYPE_NOT_FOUND",
     350  -2785 : "RSRC_CLASS_NOT_FOUND",
     351  -2786 : "DATA_ACCESS_LIST_NOT_FOUND",
     352  -2787 : "DATA_ACCESS_PRIVILEGE_NOT_FOUND",
     353  -2788 : "ACCESS_CONSTRAINT_NOT_FOUND",
     354  -2789 : "DATA_ACCESS_ID_NOT_FOUND",
     355  -2790 : "ZONE_LOCALITY_NOT_FOUND",
     356  -2791 : "ZONE_LOCN_DESC_NOT_FOUND",
     357  -2792 : "ZONE_NETPREFIX_NOT_FOUND",
     358  -2793 : "ZONE_PORT_NUM_NOT_FOUND",
     359  -2794 : "ZONE_ADMIN_AUTH_SCHEME_NAME_NOT_FOUND",
     360  -2795 : "ZONE_ADMIN_DISTIN_NAME_NOT_FOUND",
     361  -2796 : "ZONE_STATUS_NOT_FOUND",
     362  -2797 : "ZONE_CREATE_DATE_NOT_FOUND",
     363  -2798 : "ZONE_MODIFY_DATE_NOT_FOUND",
     364  -2799 : "ZONE_COMMENTS_NOT_FOUND",
     365  -2800 : "ZONE_CONTACT_NOT_FOUND",
     366  -2801 : "ZONE_ADMIN_NAME_NOT_FOUND",
     367  -2802 : "ZONE_ADMIN_DOMAIN_NAME_NOT_FOUND",
     368  -2803 : "USER_ADDRESS_NOT_FOUND",
     369  -2804 : "USER_PHONE_NOT_FOUND",
     370  -2805 : "USER_EMAIL_NOT_FOUND",
     371  -2806 : "USER_CREATE_DATE_NOT_FOUND",
     372  -2807 : "USER_MODIFY_DATE_NOT_FOUND",
     373  -2808 : "USER_DISTIN_NAME_NOT_FOUND",
     374  -2809 : "USER_GROUP_NAME_NOT_FOUND",
     375  -2810 : "USER_GROUP_ZONE_NAME_NOT_FOUND",
     376  -2811 : "USER_GROUP_DOMAIN_DESC_NOT_FOUND",
     377  -2813 : "UDSMD_USER0_NOT_FOUND",
     378  -2814 : "UDSMD_USER1_NOT_FOUND",
     379  -2815 : "UDSMD_USER2_NOT_FOUND",
     380  -2816 : "UDSMD_USER3_NOT_FOUND",
     381  -2817 : "UDSMD_USER4_NOT_FOUND",
     382  -2818 : "UDSMD_USER5_NOT_FOUND",
     383  -2819 : "UDSMD_USER6_NOT_FOUND",
     384  -2820 : "UDSMD_USER7_NOT_FOUND",
     385  -2821 : "UDSMD_USER8_NOT_FOUND",
     386  -2822 : "UDSMD_USER9_NOT_FOUND",
     387  -2823 : "UDIMD_USER0_NOT_FOUND",
     388  -2824 : "UDIMD_USER1_NOT_FOUND",
     389  -2825 : "USER_UDEF_MDATA_MODIFY_DATE_NOT_FOUND",
     390  -2827 : "RSRC_NAME_NOT_FOUND",
     391  -2828 : "LOCATION_NAME_NOT_FOUND",
     392  -2829 : "RSRC_DEFAULT_PATH_NOT_FOUND",
     393  -2830 : "RSRC_REPL_ENUM_NOT_FOUND",
     394  -2831 : "RSRC_COMMENTS_NOT_FOUND",
     395  -2832 : "RSRC_CREATE_DATE_NOT_FOUND",
     396  -2833 : "RSRC_MODIFY_DATE_NOT_FOUND",
     397  -2834 : "PHY_RSRC_NAME_NOT_FOUND",
     398  -2835 : "RSRC_MAX_OBJ_SIZE_NOT_FOUND",
     399  -2836 : "RSRC_OWNER_NAME_NOT_FOUND",
     400  -2837 : "RSRC_OWNER_DOMAIN_NOT_FOUND",
     401  -2838 : "RSRC_OWNER_ZONE_NOT_FOUND",
     402  -2840 : "RSRC_MLSEC_LATENCY_MAX_NOT_FOUND",
     403  -2841 : "RSRC_MLSEC_LATENCY_MIN_NOT_FOUND",
     404  -2842 : "RSRC_MBPS_BANDWIDTH_NOT_FOUND",
     405  -2843 : "RSRC_CONCURRENCY_MAX_NOT_FOUND",
     406  -2844 : "RSRC_NUM_OF_HIERARCHIES_NOT_FOUND",
     407  -2845 : "RSRC_NUM_OF_STRIPES_NOT_FOUND",
     408  -2846 : "RSRC_MEGAB_CAPACITY_NOT_FOUND",
     409  -2847 : "UDSMD_RSRC0_NOT_FOUND",
     410  -2848 : "UDSMD_RSRC1_NOT_FOUND",
     411  -2849 : "UDSMD_RSRC2_NOT_FOUND",
     412  -2850 : "UDSMD_RSRC3_NOT_FOUND",
     413  -2851 : "UDSMD_RSRC4_NOT_FOUND",
     414  -2852 : "UDSMD_RSRC5_NOT_FOUND",
     415  -2853 : "UDSMD_RSRC6_NOT_FOUND",
     416  -2854 : "UDSMD_RSRC7_NOT_FOUND",
     417  -2855 : "UDSMD_RSRC8_NOT_FOUND",
     418  -2856 : "UDSMD_RSRC9_NOT_FOUND",
     419  -2857 : "UDIMD_RSRC0_NOT_FOUND",
     420  -2858 : "UDIMD_RSRC1_NOT_FOUND",
     421  -2859 : "RSRC_UDEF_MDATA_MODIFY_DATE_NOT_FOUND",
     422  -2860 : "PARENT_USER_TYPE_NOT_FOUND",
     423  -2861 : "PARENT_DOMAIN_DESC_NOT_FOUND",
     424  -2862 : "RSRC_ACCS_USER_NAME_NOT_FOUND",
     425  -2863 : "RSRC_ACCS_USER_DOMAIN_NOT_FOUND",
     426  -2864 : "RSRC_ACCS_USER_ZONE_NOT_FOUND",
     427  -2865 : "LOCK_OWNERSHIP_ERROR",
     428  -2866 : "USER_IS_NOT_OWNER_ERROR",
     429  -2867 : "LOCAL_ZONE_NOT_FOUND",
     430  -2868 : "PARENT_RSRC_TYPE_NOT_FOUND",
     431  -2869 : "RSRC_ACCS_GRPUSER_NAME_NOT_FOUND",
     432  -2870 : "RSRC_ACCS_GRPUSER_DOMAIN_NOT_FOUND",
     433  -2871 : "RSRC_ACCS_GRPUSER_ZONE_NOT_FOUND",
     434  -2872 : "COLLECTION_CONT_NAME_NOT_FOUND",
     435  -2873 : "COLLECTION_NAME_NOT_FOUND",
     436  -2874 : "COLL_ACCS_ACCESS_CONSTRAINT_NOT_FOUND",
     437  -2875 : "COLL_ACCS_GRPUSER_DOMAIN_NOT_FOUND",
     438  -2876 : "COLL_ACCS_GRPUSER_NAME_NOT_FOUND",
     439  -2877 : "COLL_ACCS_GRPUSER_ZONE_NOT_FOUND",
     440  -2878 : "COLL_ANNOTATION_NOT_FOUND",
     441  -2879 : "COLL_ANNOTATION_TIMESTAMP_NOT_FOUND",
     442  -2880 : "COLL_ANNOTATION_TYPE_NOT_FOUND",
     443  -2881 : "COLL_ANNOTATION_USERDOMAIN_NOT_FOUND",
     444  -2882 : "COLL_ANNOTATION_USERNAME_NOT_FOUND",
     445  -2883 : "COLL_ANNOTATION_USER_ZONE_NOT_FOUND",
     446  -2884 : "COLL_COMMENTS_NOT_FOUND",
     447  -2885 : "COLL_CREATE_TIMESTAMP_NOT_FOUND",
     448  -2886 : "COLL_MODIFY_TIMESTAMP_NOT_FOUND",
     449  -2887 : "COLL_OWNER_DOMAIN_NOT_FOUND",
     450  -2888 : "COLL_OWNER_NAME_NOT_FOUND",
     451  -2889 : "COLL_OWNER_ZONE_NOT_FOUND",
     452  -2890 : "COLL_UDEF_MDATA_CREATE_DATE_NOT_FOUND",
     453  -2891 : "COLL_UDEF_MDATA_MODIFY_DATE_NOT_FOUND",
     454  -2892 : "CONTAINER_FOR_COLLECTION_NOT_FOUND",
     455  -2893 : "CONTAINER_LOG_RSRC_NAME_NOT_FOUND",
     456  -2894 : "CONTAINER_MAX_SIZE_NOT_FOUND",
     457  -2895 : "CONTAINER_NAME_NOT_FOUND",
     458  -2896 : "DATA_ACCS_GRPUSER_DOMAIN_NOT_FOUND",
     459  -2879 : "DATA_ACCS_GRPUSER_NAME_NOT_FOUND",
     460  -2898 : "DATA_ACCS_GRPUSER_ZONE_NOT_FOUND",
     461  -2899 : "DATA_ANNOTATION_NOT_FOUND",
     462  -2900 : "DATA_ANNOTATION_POSITION_NOT_FOUND",
     463  -2901 : "DATA_ANNOTATION_TIMESTAMP_NOT_FOUND",
     464  -2902 : "DATA_ANNOTATION_USERDOMAIN_NOT_FOUND",
     465  -2903 : "DATA_ANNOTATION_USERNAME_NOT_FOUND",
     466  -2904 : "DATA_ANNOTATION_USER_ZONE_NOT_FOUND",
     467  -2905 : "DATA_AUDITFLAG_NOT_FOUND",
     468  -2906 : "DATA_CHECKSUM_NOT_FOUND",
     469  -2907 : "DATA_COMMENTS_NOT_FOUND",
     470  -2908 : "DATA_CONT_NAME_NOT_FOUND",
     471  -2909 : "DATA_CREATE_TIMESTAMP_NOT_FOUND",
     472  -2910 : "DATA_EXPIRE_DATE_2_NOT_FOUND",
     473  -2911 : "DATA_EXPIRY_DATE_NOT_FOUND",
     474  -2912 : "DATA_HIDE_NOT_FOUND",
     475  -2913 : "DATA_IS_COMPRESSED_NOT_FOUND",
     476  -2914 : "DATA_IS_DELETED_NOT_FOUND",
     477  -2915 : "DATA_IS_ENCRYPTED_NOT_FOUND",
     478  -2916 : "DATA_LAST_ACCESS_TIMESTAMP_NOT_FOUND",
     479  -2917 : "DATA_LOCK_DESC_NOT_FOUND",
     480  -2918 : "DATA_LOCK_EXPIRY_NOT_FOUND",
     481  -2919 : "DATA_LOCK_OWNER_DOMAIN_NOT_FOUND",
     482  -2920 : "DATA_LOCK_OWNER_NAME_NOT_FOUND",
     483  -2921 : "DATA_LOCK_OWNER_ZONE_NOT_FOUND",
     484  -2922 : "DATA_NAME_NOT_FOUND",
     485  -2923 : "DATA_OWNER_DOMAIN_NOT_FOUND",
     486  -2924 : "DATA_OWNER_NOT_FOUND",
     487  -2925 : "DATA_OWNER_ZONE_NOT_FOUND",
     488  -2926 : "DATA_PIN_EXPIRY_NOT_FOUND",
     489  -2927 : "DATA_PIN_OWNER_DOMAIN_NOT_FOUND",
     490  -2928 : "DATA_PIN_OWNER_NAME_NOT_FOUND",
     491  -2929 : "DATA_PIN_OWNER_ZONE_NOT_FOUND",
     492  -2930 : "DATA_PIN_VAL_NOT_FOUND",
     493  -2931 : "DATA_REPL_ENUM_NOT_FOUND",
     494  -2932 : "DATA_SEG_NUM_NOT_FOUND",
     495  -2933 : "DATA_TYPE_FOR_CONTAINER_FOR_COLLECTION_NOT_FOUND",
     496  -2934 : "DATA_UDEF_MDATA_CREATE_DATE_NOT_FOUND",
     497  -2935 : "DATA_UDEF_MDATA_MODIFY_DATE_NOT_FOUND",
     498  -2936 : "DATA_VER_NUM_NOT_FOUND",
     499  -2937 : "DCOLLECTION_NAME",
     500  -2938 : "IS_DIRTY_NOT_FOUND",
     501  -2939 : "ITEM_ALREADY_IN_CAT",
     502  -2940 : "METADATA_NUM_COLL_NOT_FOUND",
     503  -2941 : "METADATA_NUM_NOT_FOUND",
     504  -2942 : "METADATA_NUM_RSRC_NOT_FOUND",
     505  -2943 : "METADATA_NUM_USER_NOT_FOUND",
     506  -2944 : "OFFSET_NOT_FOUND",
     507  -2945 : "PARENT_COLLECTION_NAME_NOT_FOUND",
     508  -2946 : "PATH_NAME_NOT_FOUND",
     509  -2947 : "REPL_TIMESTAMP_NOT_FOUND",
     510  -2948 : "RSRC_UDEF_MDATA_CREATE_DATE_NOT_FOUND",
     511  -2949 : "SIZE_NOT_FOUND",
     512  -2950 : "UDIMD0_NOT_FOUND",
     513  -2951 : "UDIMD1_NOT_FOUND",
     514  -2952 : "UDIMD_COLL0_NOT_FOUND",
     515  -2953 : "UDIMD_COLL1_NOT_FOUND",
     516  -2954 : "UDSMD0_NOT_FOUND",
     517  -2955 : "UDSMD1_NOT_FOUND",
     518  -2956 : "UDSMD2_NOT_FOUND",
     519  -2957 : "UDSMD3_NOT_FOUND",
     520  -2958 : "UDSMD4_NOT_FOUND",
     521  -2959 : "UDSMD5_NOT_FOUND",
     522  -2960 : "UDSMD6_NOT_FOUND",
     523  -2961 : "UDSMD7_NOT_FOUND",
     524  -2962 : "UDSMD8_NOT_FOUND",
     525  -2963 : "UDSMD9_NOT_FOUND",
     526  -2964 : "UDSMD_COLL0_NOT_FOUND",
     527  -2965 : "UDSMD_COLL1_NOT_FOUND",
     528  -2966 : "UDSMD_COLL2_NOT_FOUND",
     529  -2967 : "UDSMD_COLL3_NOT_FOUND",
     530  -2968 : "UDSMD_COLL4_NOT_FOUND",
     531  -2969 : "UDSMD_COLL5_NOT_FOUND",
     532  -2970 : "UDSMD_COLL6_NOT_FOUND",
     533  -2971 : "UDSMD_COLL7_NOT_FOUND",
     534  -2972 : "UDSMD_COLL8_NOT_FOUND",
     535  -2973 : "UDSMD_COLL9_NOT_FOUND",
     536  -2974 : "USER_UDEF_MDATA_CREATE_DATE_NOT_FOUND",
     537  -2975 : "DATA_LOCK_NUM_NOT_FOUND",
     538  -2976 : "CONTAINER_REPL_ENUM_NOT_FOUND",
     539  -2977 : "GUID_NOT_FOUND",
     540  -2978 : "GUID_FLAG_NOT_FOUND",
     541  -2979 : "GUID_TIME_STAMP_NOT_FOUND",
     542  -3001 : "MCAT_OPEN_ENV_ERROR",
     543  -3002 : "MCAT_CONNECT_ERROR",
     544  -3003 : "MCAT_CLOSE_ENV_ERROR",
     545  -3004 : "MCAT_DISCONNECT_ERROR",
     546  -3005 : "MCAT_INQUIRE_ERROR",
     547  -3006 : "MEMORY_ALLOCATION_ERROR",
     548  -3007 : "ENV_MEMORY_ALLOCATION_ERROR",
     549  -3008 : "STMT_MEMORY_ALLOCATION_ERROR",
     550  -3009 : "CONNECT_MEMORY_ALLOCATION_ERROR",
     551  -3010 : "MCAT_FREE_STMT_ERROR",
     552  -3011 : "MCAT_AUTOCOMMIT_TURNOFF_ERROR",
     553  -3012 : "MCAT_OPTION_SETTING_ERROR",
     554  -3013 : "MCAT_TRANSACT_CLOSE_ERROR",
     555  -3014 : "MCAT_CURSOR_OPEN_ERROR",
     556  -3015 : "MCAT_EXEC_ERROR",
     557  -3016 : "MCAT_NUM_RESULT_ERROR",
     558  -3017 : "MCAT_SELECT_DESCRIBE_ERROR",
     559  -3018 : "MCAT_SELECT_DEFINE_ERROR",
     560  -3019 : "MCAT_FETCH_ERROR",
     561  -3020 : "MCAT_PARSE_ERROR",
     562  -3021 : "MCAT_NO_DATA_FOUND",
     563  -3022 : "MCAT_MAX_GRAPH_PATH_OVERFLOW",
     564  -3023 : "MCAT_MAX_FKREL_ENTRIES_OVERFLOW",
     565  -3024 : "MCAT_MAX_ATTR_ENTRIES_OVERFLOW",
     566  -3025 : "MCAT_MAX_GRAPH_PATH_UNDERFLOW",
     567  -3026 : "MCAT_MAX_FKREL_ENTRIES_UNDERFLOW",
     568  -3027 : "MCAT_MAX_ATTR_ENTRIES_UNDERFLOW",
     569  -3028 : "MEMORY_FREE_ERROR",
     570  -3029 : "MCAT_NO_MORE_CONTEXTS",
     571  -3030 : "MCAT_MAX_QUERY_LIMIT_EXCEEDED",
     572  -3031 : "MCAT_RESOURCE_NOT_IN_CAT",
     573  -3032 : "MCAT_USER_NOT_IN_DOMN",
     574  -3033 : "OPERATION_NOT_IMPLEMENTED",
     575  -3034 : "QUERIES_IN_UNKNOWN_EXTERNAL_RESOURCES",
     576  -3035 : "TEMP_TABLE_ERROR",
     577  -3036 : "ERROR_IN_QUERY_EXPECTING_SELECT",
     578  -3037 : "SIZE_ERROR_IN_QUERY",
     579  -3038 : "NO_DIMENSION_FUNCTION_AVAILABLE",
     580  -3039 : "UNKNOWN_ATTRIBUTE_DIMENSION",
     581  -3050 : "DBLOBJ_PATH_NAME_ERROR",
     582  -3051 : "DBLOBJ_RESOURCE_NAME_ERROR",
     583  -3052 : "DBLOBJ_TYPE_ERROR",
     584  -3053 : "DBLOBJ_PUTENV_ERROR",
     585  -3054 : "DBLOBJ_ALLOC_ENV_ERROR",
     586  -3055 : "DBLOBJ_ALLOC_CONNECT_ERROR",
     587  -3056 : "DBLOBJ_OPTION_SETTING_ERROR",
     588  -3057 : "DBLOBJ_CONNECT_ERROR",
     589  -3058 : "DBLOBJ_ALLOC_STMT_ERROR",
     590  -3059 : "DBLOBJ_FREE_STMT_ERROR",
     591  -3060 : "DBLOBJ_DISCONNECT_ERROR",
     592  -3061 : "DBLOBJ_FREE_CONNECT_ERROR",
     593  -3062 : "DBLOBJ_FREE_ENV_ERROR",
     594  -3063 : "DBLOBJ_SIZE_ERROR",
     595  -3064 : "DBLOBJ_STATE_ALLOC_ERROR",
     596  -3101 : "METADATA_ACCESS_ERROR",
     597  -3102 : "METADATA_COUNTER_ERROR",
     598  -3103 : "METADATA_INSERTION_ERROR",
     599  -3104 : "METADATA_DELETION_ERROR",
     600  -3105 : "METADATA_UPDATE_ERROR",
     601  -3106 : "GET_TIME_ERROR",
     602  -3107 : "DATA_ID_COUNTER_ERROR",
     603  -3108 : "RSRC_ID_COUNTER_ERROR",
     604  -3109 : "METH_ID_COUNTER_ERROR",
     605  -3110 : "USER_ID_COUNTER_ERROR",
     606  -3111 : "MDAS_USER_REGISTRATION_ERROR",
     607  -3112 : "MDAS_DATA_REGISTRATION_ERROR",
     608  -3113 : "MDAS_RSRC_REGISTRATION_ERROR",
     609  -3114 : "MDAS_METH_REGISTRATION_ERROR",
     610  -3115 : "MDAS_USER_GROUP_REGISTRATION_ERROR",
     611  -3116 : "MDAS_HIERARCHY_ERROR",
     612  -3117 : "MDAS_HIERARCHY_OVERFLOW_ERROR",
     613  -3118 : "TOKEN_NOT_IN_CAT",
     614  -3119 : "TOKEN_ALREADY_IN_CAT",
     615  -3120 : "INVALID_TICKET",
     616  -3121 : "NAME2LONG_ERROR",
     617  -3151 : "MDAS_CATALOG_MODIFY_TYPE_ERROR",
     618  -3152 : "MDAS_CATALOG_TYPE_ERROR",
     619  -3153 : "UNIX_PUTENV_ERROR",
     620  -3154 : "DATA_VALUE_TYPE_ERROR",
     621  -3155 : "INIT_ENVIRON_ERROR",
     622  -3156 : "MDAS_CONFIG_FILE_ERROR",
     623  -3157 : "MDAS_CATALOG_DIR_INFO_ERROR",
     624  -3158 : "USER_PATH_NAME_EXPECTED",
     625  -3159 : "NOT_A_SERVER_FUNCTION",
     626  -3201 : "DATA_NOT_IN_CAT",
     627  -3202 : "DATA_NOT_IN_DOMN",
     628  -3203 : "USER_NOT_IN_DOMN",
     629  -3204 : "NO_DATA_ACCS_TO_USER",
     630  -3205 : "NO_DATA_ACCS_TO_USER_IN_DOMN",
     631  -3206 : "USER_AUTHORIZATION_ERROR",
     632  -3207 : "SYS_USER_AUTHORIZATION_ERROR",
     633  -3208 : "USER_NOT_IN_CAT",
     634  -3209 : "NO_DATA_REPLICA_IN_CAT",
     635  -3210 : "DATA_NOT_UNIQUE_IN_COLLECTION",
     636  -3211 : "USER_GROUP_NOT_IN_CAT",
     637  -3212 : "USER_NOT_UNIQUE_IN_CAT",
     638  -3213 : "DATA_NOT_UNIQUE_IN_PATH",
     639  -3214 : "MDAS_OBJ_NOT_IN_DOMN",
     640  -3215 : "RESOURCE_NOT_IN_CAT",
     641  -3216 : "RESOURCE_NOT_IN_DOMAIN",
     642  -3217 : "DATA_NOT_IN_RESOURCE_OR_PATH",
     643  -3218 : "USER_NOT_UNIQUE_IN_DOMN",
     644  -3219 : "DATA_SUBCOLLECTION_NOT_UNIQUE",
     645  -3220 : "NO_ACCS_TO_USER_IN_COLLECTION",
     646  -3221 : "COLLECTION_NOT_IN_CAT",
     647  -3222 : "DATA_NOT_IN_COLLECTION",
     648  -3223 : "NO_MODIFY_DATA_ACCS_TO_USER",
     649  -3224 : "DATA_TYPE_NOT_IN_CAT",
     650  -3225 : "DOMAIN_NOT_IN_CAT",
     651  -3226 : "ACCESS_TYPE_NOT_IN_CAT",
     652  -3227 : "USER_TYPE_NOT_IN_CAT",
     653  -3228 : "ACTION_TYPE_NOT_IN_CAT",
     654  -3229 : "COLLECTION_ALREADY_IN_CAT",
     655  -3230 : "COLLECTION_NOT_EMPTY",
     656  -3231 : "RESOURCE_ALREADY_IN_CAT",
     657  -3232 : "LOGICAL_RESOURCE_ALREADY_IN_CAT",
     658  -3233 : "LOGICAL_RESOURCE_NOT_IN_CAT",
     659  -3234 : "REGISTRATION_PERMITS_INADEQUATE",
     660  -3235 : "ERROR_IN_GIVEN_PATH",
     661  -3236 : "ERROR_IN_DEFAULT_PATH",
     662  -3237 : "ERROR_IN_QUERY_CONDITION",
     663  -3238 : "NO_DATA_ACCS_TO_TICKET",
     664  -3239 : "ATTRIBUTE_VALUE_REQUIRED",
     665  -3240 : "ERROR_IN_SQL_GENERATION",
     666  -3241 : "INCOMPATIBLE_ATTRIBUTE_TYPE",
     667  -3242 : "NONUNIQUE_METADATA_ERROR",
     668  -3243 : "NO_VALUE_FOUND",
     669  -3244 : "DATE_ATTRIBUTE_VALUE_REQUIRED",
     670  -3245 : "RANDOM_ATTRIBUTE_VALUE_REQUIRED",
     671  -3246 : "PARENT_ATTRIBUTE_VALUE_REQUIRED",
     672  -3247 : "UNKNOWN_ATTRIBUTE_ID",
     673  -3248 : "UNKNOWN_USER_SCHEMASET",
     674  -3249 : "UNKNOWN_SCHEMA_NAME",
     675  -3250 : "SIZE_OF_ATTRIBUTE_UNKNOWN",
     676  -3251 : "UNABLE_TO_MAKE_UNIQUE_ATTRIBUTE_NAME",
     677  -3252 : "UNABLE_TO_MAKE_UNIQUE_TABLE_NAME",
     678  -3253 : "ATTRIBUTE_ID_COUNTER_ERROR",
     679  -3254 : "TABLE_ID_COUNTER_ERROR",
     680  -3255 : "INSERT_INTO_NONLOCAL_MCAT_DATABASE",
     681  -3256 : "SCHEMA_NAME_NOT_UNIQUE_IN_CAT",
     682  -3257 : "TABLE_METADATA_INSERTION_ERROR",
     683  -3258 : "ATTRIBUTE_METADATA_INSERTION_ERROR",
     684  -3259 : "MCAT_TABLE_CREATION_ERROR",
     685  -3260 : "MCAT_SCHEMA_CREATION_ERROR",
     686  -3261 : "COLUMN_COUNT_MISMATCH",
     687  -3262 : "INVALID_TOKEN_NAME",
     688  -3263 : "TOKEN_IDEN_TYPE_ERROR",
     689  -3264 : "FKREL_METADATA_INSERTION_ERROR",
     690  -3265 : "ACTION_NOT_ALLOWED_FOR_USER",
     691  -3266 : "DELETE_ATTR_ERROR",
     692  -3267 : "DELETE_SCHEMA_ERROR",
     693  -3268 : "INSERT_ATTR_ERROR",
     694  -3269 : "INNER_CORE_SCHEMA_CANNOT_BE_DELETED",
     695  -3270 : "ATTRIBUTE_SET_EMPTY",
     696  -3271 : "TEMP_TABLE_INSERTION_ERROR",
     697  -3272 : "TEMP_TABLE_CREATE_ERROR",
     698  -3273 : "EXEC_SQL_FAILED",
     699  -3274 : "GET_COLUMN_COUNT_FAILED",
     700  -3275 : "BIND_ROW_FAILED",
     701  -3276 : "GET_ROW_FAILED",
     702  -3277 : "MISSING_PRIOR_CREATE",
     703  -3278 : "ERROR_IN_QUERY_FORMATION",
     704  -3279 : "ERROR_IN_QUERY_UNKNOWN_QUERY",
     705  -3280 : "ERROR_IN_QUERY",
     706  -3281 : "ERROR_IN_UPDATE_QUERY_FORMATION",
     707  -3282 : "UNKNOWN_FUNCTION_MAP_ID",
     708  -3283 : "TABLE_LOCK_ERROR",
     709  -3284 : "NO_ACCS_TO_USER_IN_CONTAINER",
     710  -3285 : "DATA_TYPE_COMPATIBILITY_FAILURE",
     711  -3286 : "CONTAINER_NOT_UNIQUE",
     712  -3287 : "NOT_IN_CONTAINER_OBJECT",
     713  -3288 : "ACTION_NOT_ALLOWED_ON_IN_CONTAINER_OBJECT",
     714  -3289 : "FK_REL_TABLE_ID_ERROR",
     715  -3290 : "FOREIGN_REFERENCE_ERROR",
     716  -3291 : "CLUSTER_SCHEMA_EXISTS",
     717  -3292 : "ACTION_NOT_ALLOWED_ON_CONTAINER_OBJECT",
     718  -3293 : "ERROR_IN_CREATE_STRING",
     719  -3294 : "CONTAINER_NOT_IN_CAT",
     720  -3295 : "CONTAINER_NOT_EMPTY",
     721  -3296 : "RESOURCE_CLASS_NOT_IN_CAT",
     722  -3297 : "DB_UNIQUE_CONSTRAINT_VIOLATION",
     723  -3298 : "UNKNOWN_ATTRIBUTE_NAME",
     724  -3299 : "METADATA_FORM_ERROR",
     725  -3300 : "MDAS_AD_COMMENTS_APPEND_ERROR",
     726  -3301 : "NO_ACCS_TO_USER_IN_PHYSICAL_RESOURCE",
     727  -3302 : "NO_MODIFY_RSRC_ACCS_TO_USER",
     728  -3303 : "ACTION_NOT_ALLOWED",
     729  -3304 : "COLLECTION_NAME_ERROR",
     730  -3305 : "COMPOUND_RESOURCE_NOT_IN_CAT",
     731  -3306 : "PHYSICAL_RESOURCE_NOT_IN_CAT",
     732  -3307 : "ERROR_IN_COMPOUND_RESOURCE_NAME",
     733  -3308 : "INTERNAL_COMPOUND_OBJECT_IS_NOT_UNIQUE",
     734  -3309 : "COMPOUND_OBJECT_NOT_EMPTY",
     735  -3310 : "USER_HAS_INSUFFICIENT_PRIVILEGE",
     736  -3311 : "DATA_PIN_OWNERSHIP_ERROR",
     737  -3312 : "ZONE_NAME_ALREADY_EXISTS",
     738  -3313 : "LOCAL_ZONE_ALREADY_EXISTS",
     739  -3314 : "ZONE_NAME_NOT_IN_CAT",
     740  -3315 : "ACTION_NOT_ALLOWED_ON_IN_CONTAINER_OR_LINKED_OBJECT",
     741  -3316 : "ACTION NOT ALLOWED AS OLD EXTERNAL GUID EXISTS",
     742  -3317 : "USER_NOT_CURATOR_ERROR",
     743  -3318 : "DATASCOPE_ROW_INCOMPLETE",
     744  -3319 : "MD_CONNECT_ERROR",
     745  -3320 : "MD_SET_ERROR",
     746  -3321 : "MD_CLOSE_ERROR",
     747  -3322 : "MD_BUF_LENGTH_INSUFFICIENT",
     748  -3323 : "MD_READ_ERROR",
     749  -3324 : "MD_SEEK_ERROR",
     750  -3325 : "MD_PRESENTATION_ERROR",
     751  -3326 : "DATASCOPE_COMPILATION_ERROR",
     752  -3327 : "DATASCOPE_END_OF_DATA_FOUND",
     753  -3328 : "DATASCOPE_BEGIN_OF_DATA_FOUND",
     754  -3329 : "TMP_FILE_WRITE_ERROR",
     755  -3401 : "MDAS_TD_LOCK_INSERTION_ERROR",
     756  -3402 : "MDAS_TD_DOMN_INSERTION_ERROR",
     757  -3403 : "MDAS_TD_DATA_GRP_INSERTION_ERROR",
     758  -3404 : "MDAS_TD_DATA_TYP_INSERTION_ERROR",
     759  -3405 : "MDAS_TD_METH_TYP_INSERTION_ERROR",
     760  -3406 : "MDAS_TD_RSRC_TYP_INSERTION_ERROR",
     761  -3407 : "MDAS_TD_USER_TYP_INSERTION_ERROR",
     762  -3408 : "MDAS_TD_EXEC_TYP_INSERTION_ERROR",
     763  -3409 : "MDAS_TD_LOCN_INSERTION_ERROR",
     764  -3410 : "MDAS_TD_RSRC_FUNC_INSERTION_ERROR",
     765  -3411 : "MDAS_TD_DS_FLDTYP_INSERTION_ERROR",
     766  -3412 : "MDAS_TD_DS_SCHM_INSERTION_ERROR",
     767  -3413 : "MDAS_TD_DS_SCHMDSC_INSERTION_ERROR",
     768  -3414 : "MDAS_TD_SPEC_SUMM_INSERTION_ERROR",
     769  -3415 : "MDAS_TD_ACTN_INSERTION_ERROR",
     770  -3416 : "MDAS_TD_TCKT_INSERTION_ERROR",
     771  -3417 : "MDAS_TD_AUTH_INSERTION_ERROR",
     772  -3418 : "MDAS_TD_VERI_INSERTION_ERROR",
     773  -3419 : "MDAS_TD_ENCR_INSERTION_ERROR",
     774  -3420 : "MDAS_TD_DECR_INSERTION_ERROR",
     775  -3421 : "MDAS_TD_RSRC_ACCS_INSERTION_ERROR",
     776  -3422 : "MDAS_TD_METH_ACCS_INSERTION_ERROR",
     777  -3423 : "MDAS_TD_DS_ACCS_INSERTION_ERROR",
     778  -3424 : "MDAS_CD_DATA_INSERTION_ERROR",
     779  -3425 : "MDAS_CD_METH_INSERTION_ERROR",
     780  -3426 : "MDAS_CD_RSRC_INSERTION_ERROR",
     781  -3427 : "MDAS_CD_USER_INSERTION_ERROR",
     782  -3428 : "MDAS_TD_REPL_TYP_INSERTION_ERROR",
     783  -3429 : "MDAS_TD_DS_REPPLCY_INSERTION_ERROR",
     784  -3430 : "MDAS_TD_DS_PRTPLCY_INSERTION_ERROR",
     785  -3431 : "MDAS_TD_DS_TRIG_INSERTION_ERROR",
     786  -3432 : "MDAS_TD_DS_AGGR_INSERTION_ERROR",
     787  -3433 : "MDAS_TD_MTHREP_PLC_INSERTION_ERROR",
     788  -3434 : "MDAS_TD_RSRREP_PLC_INSERTION_ERROR",
     789  -3435 : "MDAS_AD_ALIAS_INSERTION_ERROR",
     790  -3436 : "MDAS_AD_DOMN_INSERTION_ERROR",
     791  -3437 : "MDAS_AD_AUTH_KEY_INSERTION_ERROR",
     792  -3438 : "MDAS_AD_REPL_INSERTION_ERROR",
     793  -3439 : "MDAS_AD_COMMENTS_INSERTION_ERROR",
     794  -3440 : "MDAS_AD_LOCK_INSERTION_ERROR",
     795  -3441 : "MDAS_AD_ACCS_INSERTION_ERROR",
     796  -3442 : "MDAS_AD_PART_INSERTION_ERROR",
     797  -3443 : "MDAS_AD_AGGR_INSERTION_ERROR",
     798  -3444 : "MDAS_AD_SUMM_INSERTION_ERROR",
     799  -3445 : "MDAS_AD_TRIG_INSERTION_ERROR",
     800  -3446 : "MDAS_AD_AUDIT_INSERTION_ERROR",
     801  -3447 : "MDAS_AD_LIN_DATA_INSERTION_ERROR",
     802  -3448 : "MDAS_AD_LIN_METH_INSERTION_ERROR",
     803  -3449 : "MDAS_AD_LIN_USER_INSERTION_ERROR",
     804  -3450 : "MDAS_AD_LIN_PARM_INSERTION_ERROR",
     805  -3451 : "MDAS_AD_LIN_RSRC_INSERTION_ERROR",
     806  -3452 : "MDAS_AD_FON_DATA_INSERTION_ERROR",
     807  -3453 : "MDAS_AD_SD_INSERTION_ERROR",
     808  -3454 : "MDAS_AD_TYP_SD_INSERTION_ERROR",
     809  -3455 : "MDAS_AM_ALIAS_INSERTION_ERROR",
     810  -3456 : "MDAS_AM_DOMN_INSERTION_ERROR",
     811  -3457 : "MDAS_AM_AUTH_KEY_INSERTION_ERROR",
     812  -3458 : "MDAS_AM_DECR_KEY_INSERTION_ERROR",
     813  -3459 : "MDAS_AM_REPL_INSERTION_ERROR",
     814  -3460 : "MDAS_AM_COMMENTS_INSERTION_ERROR",
     815  -3461 : "MDAS_AM_LOCK_INSERTION_ERROR",
     816  -3462 : "MDAS_AM_ACCS_INSERTION_ERROR",
     817  -3463 : "MDAS_AM_SUMM_INSERTION_ERROR",
     818  -3464 : "MDAS_AM_AUDIT_INSERTION_ERROR",
     819  -3465 : "MDAS_AM_LIN_METH_INSERTION_ERROR",
     820  -3466 : "MDAS_AM_LIN_DATA_INSERTION_ERROR",
     821  -3467 : "MDAS_AM_LIN_USER_INSERTION_ERROR",
     822  -3468 : "MDAS_AM_LIN_PARM_INSERTION_ERROR",
     823  -3469 : "MDAS_AM_LIN_RSRC_INSERTION_ERROR",
     824  -3470 : "MDAS_AM_CNVT_MTHID_INSERTION_ERROR",
     825  -3471 : "MDAS_AM_CNVT_MTHTY_INSERTION_ERROR",
     826  -3472 : "MDAS_AM_APPL_PARM_INSERTION_ERROR",
     827  -3473 : "MDAS_AM_APPL_OUT_INSERTION_ERROR",
     828  -3474 : "MDAS_AM_APPL_IN_INSERTION_ERROR",
     829  -3475 : "MDAS_AM_APPL_RQR_INSERTION_ERROR",
     830  -3476 : "MDAS_AM_APPL_PRED_INSERTION_ERROR",
     831  -3477 : "MDAS_AM_COMP_MAP_INSERTION_ERROR",
     832  -3478 : "MDAS_AM_COMP_MAPDS_INSERTION_ERROR",
     833  -3479 : "MDAS_AM_COMP_MAPPR_INSERTION_ERROR",
     834  -3480 : "MDAS_AM_SD_INSERTION_ERROR",
     835  -3481 : "MDAS_AM_TYP_SD_INSERTION_ERROR",
     836  -3482 : "MDAS_AR_ALIAS_INSERTION_ERROR",
     837  -3483 : "MDAS_AR_DOMN_INSERTION_ERROR",
     838  -3484 : "MDAS_AR_AUTH_KEY_INSERTION_ERROR",
     839  -3485 : "MDAS_AR_DECR_KEY_INSERTION_ERROR",
     840  -3486 : "MDAS_AR_REPL_INSERTION_ERROR",
     841  -3487 : "MDAS_AR_COMMENTS_INSERTION_ERROR",
     842  -3488 : "MDAS_AR_LOCK_INSERTION_ERROR",
     843  -3489 : "MDAS_AR_ACCS_INSERTION_ERROR",
     844  -3490 : "MDAS_AR_SUMM_INSERTION_ERROR",
     845  -3491 : "MDAS_AR_AUDIT_INSERTION_ERROR",
     846  -3492 : "MDAS_AR_LIN_RSRC_INSERTION_ERROR",
     847  -3493 : "MDAS_AR_LIN_METH_INSERTION_ERROR",
     848  -3494 : "MDAS_AR_LIN_USER_INSERTION_ERROR",
     849  -3495 : "MDAS_AR_LIN_PARM_INSERTION_ERROR",
     850  -3496 : "MDAS_AR_LIN_DATA_INSERTION_ERROR",
     851  -3497 : "MDAS_AR_FON_RSRC_INSERTION_ERROR",
     852  -3498 : "MDAS_AR_APPL_PRED_INSERTION_ERROR",
     853  -3499 : "MDAS_AR_SD_INSERTION_ERROR",
     854  -3500 : "MDAS_AR_TYP_SD_INSERTION_ERROR",
     855  -3501 : "MDAS_AU_INFO_INSERTION_ERROR",
     856  -3502 : "MDAS_AU_ALIAS_INSERTION_ERROR",
     857  -3503 : "MDAS_AU_GROUP_INSERTION_ERROR",
     858  -3504 : "MDAS_AU_DOMN_INSERTION_ERROR",
     859  -3505 : "MDAS_AU_AUTH_KEY_INSERTION_ERROR",
     860  -3506 : "MDAS_AU_DECR_KEY_INSERTION_ERROR",
     861  -3507 : "MDAS_AU_SUMM_INSERTION_ERROR",
     862  -3508 : "MDAS_AU_AUDIT_INSERTION_ERROR",
     863  -3509 : "MDAS_AU_SD_INSERTION_ERROR",
     864  -3510 : "MDAS_AU_TYP_SD_INSERTION_ERROR",
     865  -3511 : "MDAS_COUNTER_INSERTION_ERROR",
     866  -3512 : "MDAS_SD_KEYWORD_INSERTION_ERROR",
     867  -3513 : "MDAS_TD_DATA_ACCS_INSERTION_ERROR",
     868  -3514 : "MDAS_AD_ACCESS_INSERTION_ERROR",
     869  -3515 : "MDAS_AD_GRP_ACCS_INSERTION_ERROR",
     870  -3516 : "MDAS_AR_PHYSICAL_INSERTION_ERROR",
     871  -3517 : "MDAS_AU_TCKT_DATA_INSERTION_ERROR",
     872  -3518 : "MDAS_AU_TCKT_GRP_INSERTION_ERROR",
     873  -3519 : "MDAS_AR_DB_RSRC_INSERTION_ERROR",
     874  -3520 : "MDAS_TD_CONTAINER_INSERTION_ERROR",
     875  -3521 : "MDAS_TD_RSRC_CLASS_INSERTION_ERROR",
     876  -3522 : "MDAS_AU_AUTH_MAP_INSERTION_ERROR",
     877  -3523 : "MDAS_AR_AUTH_INSERTION_ERROR",
     878  -3524 : "MDAS_TD_AUTH_SCHM_INSERTION_ERROR",
     879  -3525 : "MDAS_AD_ANNOTATION_INSERTION_ERROR",
     880  -3526 : "MDAS_AD_CLASS_INSERTION_ERROR",
     881  -3527 : "MDAS_AD_DATA_INDEX_INSERTION_ERROR",
     882  -3528 : "MDAS_AD_DTYP_INDEX_INSERTION_ERROR",
     883  -3529 : "MDAS_AD_COLL_INDEX_INSERTION_ERROR",
     884  -3530 : "MDAS_AD_DATA_METH_INSERTION_ERROR",
     885  -3531 : "MDAS_AD_DTYP_METH_INSERTION_ERROR",
     886  -3532 : "MDAS_AD_COLL_METH_INSERTION_ERROR",
     887  -3533 : "MDAS_AD_STRCT_BLOB_INSERTION_ERROR",
     888  -3534 : "MDAS_AD_MDATA_INSERTION_ERROR",
     889  -3535 : "MDAS_AD_COLLCONT_INSERTION_ERROR",
     890  -3536 : "MDAS_AD_COLLMDATA_INSERTION_ERROR",
     891  -3537 : "MDAS_AC_ANNOTATION_INSERTION_ERROR",
     892  -3538 : "MDAS_AR_CMPND_RSRC_INSERTION_ERROR",
     893  -3539 : "MDAS_AD_COMPOUND_INSERTION_ERROR",
     894  -3540 : "MDAS_AR_TAPE_INFO_INSERTION_ERROR",
     895  -3541 : "MDAS_AD_MISC1_INSERTION_ERROR",
     896  -3542 : "MDAS_AU_MDATA_INSERTION_ERROR",
     897  -3543 : "MDAS_AR_MDATA_INSERTION_ERROR",
     898  -3544 : "MDAS_TD_ZONE_INSERTION_ERROR",
     899  -3545 : "MDAS_AD_GUID_INSERTION_ERROR",
     900  -3546 : "MDAS_AR_INFO_INSERTION_ERROR",
     901  -3547 : "MDAS_AR_DAILY_TOT_INSERTION_ERROR",
     902  -3548 : "MDAS_AR_USE_QUOTA_INSERTION_ERROR",
     903  -3601 : "MDAS_TD_LOCK_DELETION_ERROR",
     904  -3602 : "MDAS_TD_DOMN_DELETION_ERROR",
     905  -3603 : "MDAS_TD_DATA_GRP_DELETION_ERROR",
     906  -3604 : "MDAS_TD_DATA_TYP_DELETION_ERROR",
     907  -3605 : "MDAS_TD_METH_TYP_DELETION_ERROR",
     908  -3606 : "MDAS_TD_RSRC_TYP_DELETION_ERROR",
     909  -3607 : "MDAS_TD_USER_TYP_DELETION_ERROR",
     910  -3608 : "MDAS_TD_EXEC_TYP_DELETION_ERROR",
     911  -3609 : "MDAS_TD_LOCN_DELETION_ERROR",
     912  -3610 : "MDAS_TD_RSRC_FUNC_DELETION_ERROR",
     913  -3611 : "MDAS_TD_DS_FLDTYP_DELETION_ERROR",
     914  -3612 : "MDAS_TD_DS_SCHM_DELETION_ERROR",
     915  -3613 : "MDAS_TD_DS_SCHMDSC_DELETION_ERROR",
     916  -3614 : "MDAS_TD_SPEC_SUMM_DELETION_ERROR",
     917  -3615 : "MDAS_TD_ACTN_DELETION_ERROR",
     918  -3616 : "MDAS_TD_TCKT_DELETION_ERROR",
     919  -3617 : "MDAS_TD_AUTH_DELETION_ERROR",
     920  -3618 : "MDAS_TD_VERI_DELETION_ERROR",
     921  -3619 : "MDAS_TD_ENCR_DELETION_ERROR",
     922  -3620 : "MDAS_TD_DECR_DELETION_ERROR",
     923  -3621 : "MDAS_TD_RSRC_ACCS_DELETION_ERROR",
     924  -3622 : "MDAS_TD_METH_ACCS_DELETION_ERROR",
     925  -3623 : "MDAS_TD_DS_ACCS_DELETION_ERROR",
     926  -3624 : "MDAS_CD_DATA_DELETION_ERROR",
     927  -3625 : "MDAS_CD_METH_DELETION_ERROR",
     928  -3626 : "MDAS_CD_RSRC_DELETION_ERROR",
     929  -3627 : "MDAS_CD_USER_DELETION_ERROR",
     930  -3628 : "MDAS_TD_REPL_TYP_DELETION_ERROR",
     931  -3629 : "MDAS_TD_DS_REPPLCY_DELETION_ERROR",
     932  -3630 : "MDAS_TD_DS_PRTPLCY_DELETION_ERROR",
     933  -3631 : "MDAS_TD_DS_TRIG_DELETION_ERROR",
     934  -3632 : "MDAS_TD_DS_AGGR_DELETION_ERROR",
     935  -3633 : "MDAS_TD_MTHREP_PLC_DELETION_ERROR",
     936  -3634 : "MDAS_TD_RSRREP_PLC_DELETION_ERROR",
     937  -3635 : "MDAS_AD_ALIAS_DELETION_ERROR",
     938  -3636 : "MDAS_AD_DOMN_DELETION_ERROR",
     939  -3637 : "MDAS_AD_AUTH_KEY_DELETION_ERROR",
     940  -3638 : "MDAS_AD_REPL_DELETION_ERROR",
     941  -3639 : "MDAS_AD_COMMENTS_DELETION_ERROR",
     942  -3640 : "MDAS_AD_LOCK_DELETION_ERROR",
     943  -3641 : "MDAS_AD_ACCS_DELETION_ERROR",
     944  -3642 : "MDAS_AD_PART_DELETION_ERROR",
     945  -3643 : "MDAS_AD_AGGR_DELETION_ERROR",
     946  -3644 : "MDAS_AD_SUMM_DELETION_ERROR",
     947  -3645 : "MDAS_AD_TRIG_DELETION_ERROR",
     948  -3646 : "MDAS_AD_AUDIT_DELETION_ERROR",
     949  -3647 : "MDAS_AD_LIN_DATA_DELETION_ERROR",
     950  -3648 : "MDAS_AD_LIN_METH_DELETION_ERROR",
     951  -3649 : "MDAS_AD_LIN_USER_DELETION_ERROR",
     952  -3650 : "MDAS_AD_LIN_PARM_DELETION_ERROR",
     953  -3651 : "MDAS_AD_LIN_RSRC_DELETION_ERROR",
     954  -3652 : "MDAS_AD_FON_DATA_DELETION_ERROR",
     955  -3653 : "MDAS_AD_SD_DELETION_ERROR",
     956  -3654 : "MDAS_AD_TYP_SD_DELETION_ERROR",
     957  -3655 : "MDAS_AM_ALIAS_DELETION_ERROR",
     958  -3656 : "MDAS_AM_DOMN_DELETION_ERROR",
     959  -3657 : "MDAS_AM_AUTH_KEY_DELETION_ERROR",
     960  -3658 : "MDAS_AM_DECR_KEY_DELETION_ERROR",
     961  -3659 : "MDAS_AM_REPL_DELETION_ERROR",
     962  -3660 : "MDAS_AM_COMMENTS_DELETION_ERROR",
     963  -3661 : "MDAS_AM_LOCK_DELETION_ERROR",
     964  -3662 : "MDAS_AM_ACCS_DELETION_ERROR",
     965  -3663 : "MDAS_AM_SUMM_DELETION_ERROR",
     966  -3664 : "MDAS_AM_AUDIT_DELETION_ERROR",
     967  -3665 : "MDAS_AM_LIN_METH_DELETION_ERROR",
     968  -3666 : "MDAS_AM_LIN_DATA_DELETION_ERROR",
     969  -3667 : "MDAS_AM_LIN_USER_DELETION_ERROR",
     970  -3668 : "MDAS_AM_LIN_PARM_DELETION_ERROR",
     971  -3669 : "MDAS_AM_LIN_RSRC_DELETION_ERROR",
     972  -3670 : "MDAS_AM_CNVT_MTHID_DELETION_ERROR",
     973  -3671 : "MDAS_AM_CNVT_MTHTY_DELETION_ERROR",
     974  -3672 : "MDAS_AM_APPL_PARM_DELETION_ERROR",
     975  -3673 : "MDAS_AM_APPL_OUT_DELETION_ERROR",
     976  -3674 : "MDAS_AM_APPL_IN_DELETION_ERROR",
     977  -3675 : "MDAS_AM_APPL_RQR_DELETION_ERROR",
     978  -3676 : "MDAS_AM_APPL_PRED_DELETION_ERROR",
     979  -3677 : "MDAS_AM_COMP_MAP_DELETION_ERROR",
     980  -3678 : "MDAS_AM_COMP_MAPDS_DELETION_ERROR",
     981  -3679 : "MDAS_AM_COMP_MAPPR_DELETION_ERROR",
     982  -3680 : "MDAS_AM_SD_DELETION_ERROR",
     983  -3681 : "MDAS_AM_TYP_SD_DELETION_ERROR",
     984  -3682 : "MDAS_AR_ALIAS_DELETION_ERROR",
     985  -3683 : "MDAS_AR_DOMN_DELETION_ERROR",
     986  -3684 : "MDAS_AR_AUTH_KEY_DELETION_ERROR",
     987  -3685 : "MDAS_AR_DECR_KEY_DELETION_ERROR",
     988  -3686 : "MDAS_AR_REPL_DELETION_ERROR",
     989  -3687 : "MDAS_AR_COMMENTS_DELETION_ERROR",
     990  -3688 : "MDAS_AR_LOCK_DELETION_ERROR",
     991  -3689 : "MDAS_AR_ACCS_DELETION_ERROR",
     992  -3690 : "MDAS_AR_SUMM_DELETION_ERROR",
     993  -3691 : "MDAS_AR_AUDIT_DELETION_ERROR",
     994  -3692 : "MDAS_AR_LIN_RSRC_DELETION_ERROR",
     995  -3693 : "MDAS_AR_LIN_METH_DELETION_ERROR",
     996  -3694 : "MDAS_AR_LIN_USER_DELETION_ERROR",
     997  -3695 : "MDAS_AR_LIN_PARM_DELETION_ERROR",
     998  -3696 : "MDAS_AR_LIN_DATA_DELETION_ERROR",
     999  -3697 : "MDAS_AR_FON_RSRC_DELETION_ERROR",
    1000  -3698 : "MDAS_AR_APPL_PRED_DELETION_ERROR",
    1001  -3699 : "MDAS_AR_SD_DELETION_ERROR",
    1002  -3700 : "MDAS_AR_TYP_SD_DELETION_ERROR",
    1003  -3701 : "MDAS_AU_INFO_DELETION_ERROR",
    1004  -3702 : "MDAS_AU_ALIAS_DELETION_ERROR",
    1005  -3703 : "MDAS_AU_GROUP_DELETION_ERROR",
    1006  -3704 : "MDAS_AU_DOMN_DELETION_ERROR",
    1007  -3705 : "MDAS_AU_AUTH_KEY_DELETION_ERROR",
    1008  -3706 : "MDAS_AU_DECR_KEY_DELETION_ERROR",
    1009  -3707 : "MDAS_AU_SUMM_DELETION_ERROR",
    1010  -3708 : "MDAS_AU_AUDIT_DELETION_ERROR",
    1011  -3709 : "MDAS_AU_SD_DELETION_ERROR",
    1012  -3710 : "MDAS_AU_TYP_SD_DELETION_ERROR",
    1013  -3711 : "MDAS_COUNTER_DELETION_ERROR",
    1014  -3712 : "MDAS_SD_KEYWORD_DELETION_ERROR",
    1015  -3713 : "MDAS_TD_DATA_ACCS_DELETION_ERROR",
    1016  -3714 : "MDAS_AD_ACCESS_DELETION_ERROR",
    1017  -3715 : "MDAS_AD_GRP_ACCS_DELETION_ERROR",
    1018  -3716 : "MDAS_AR_PHYSICAL_DELETION_ERROR",
    1019  -3717 : "MDAS_AU_TCKT_DATA_DELETION_ERROR",
    1020  -3718 : "MDAS_AU_TCKT_GRP_DELETION_ERROR",
    1021  -3719 : "MDAS_AR_DB_RSRC_DELETION_ERROR",
    1022  -3720 : "MDAS_TD_CONTAINER_DELETION_ERROR",
    1023  -3721 : "MDAS_TD_RSRC_CLASS_DELETION_ERROR",
    1024  -3722 : "MDAS_AU_AUTH_MAP_DELETION_ERROR",
    1025  -3723 : "MDAS_AR_AUTH_DELETION_ERROR",
    1026  -3724 : "MDAS_TD_AUTH_SCHM_DELETION_ERROR",
    1027  -3725 : "MDAS_AD_ANNOTATION_DELETION_ERROR",
    1028  -3726 : "MDAS_AD_CLASS_DELETION_ERROR",
    1029  -3727 : "MDAS_AD_DATA_INDEX_DELETION_ERROR",
    1030  -3728 : "MDAS_AD_DTYP_INDEX_DELETION_ERROR",
    1031  -3729 : "MDAS_AD_COLL_INDEX_DELETION_ERROR",
    1032  -3730 : "MDAS_AD_DATA_METH_DELETION_ERROR",
    1033  -3731 : "MDAS_AD_DTYP_METH_DELETION_ERROR",
    1034  -3732 : "MDAS_AD_COLL_METH_DELETION_ERROR",
    1035  -3733 : "MDAS_AD_STRCT_BLOB_DELETION_ERROR",
    1036  -3734 : "MDAS_AD_MDATA_DELETION_ERROR",
    1037  -3735 : "MDAS_AD_COLLCONT_DELETION_ERROR",
    1038  -3736 : "MDAS_AD_COLLMDATA_DELETION_ERROR",
    1039  -3737 : "MDAS_AC_ANNOTATION_DELETION_ERROR",
    1040  -3738 : "MDAS_AR_CMPND_RSRC_DELETION_ERROR",
    1041  -3739 : "MDAS_AD_COMPOUND_DELETION_ERROR",
    1042  -3740 : "MDAS_AR_TAPE_INFO_DELETION_ERROR",
    1043  -3741 : "MDAS_AD_MISC1_DELETION_ERROR",
    1044  -3742 : "MDAS_AU_MDATA_DELETION_ERROR",
    1045  -3743 : "MDAS_AR_MDATA_DELETION_ERROR",
    1046  -3744 : "MDAS_TD_ZONE_DELETION_ERROR",
    1047  -3745 : "MDAS_AD_GUID_DELETION_ERROR",
    1048  -3746 : "MDAS_AR_INFO_DELETION_ERROR",
    1049  -3747 : "MDAS_AR_DAILY_TOT_DELETION_ERROR",
    1050  -3748 : "MDAS_AR_USE_QUOTA_DELETION_ERROR",
    1051  -3801 : "MDAS_TD_LOCK_UPDATE_ERROR",
    1052  -3802 : "MDAS_TD_DOMN_UPDATE_ERROR",
    1053  -3803 : "MDAS_TD_DATA_GRP_UPDATE_ERROR",
    1054  -3804 : "MDAS_TD_DATA_TYP_UPDATE_ERROR",
    1055  -3805 : "MDAS_TD_METH_TYP_UPDATE_ERROR",
    1056  -3806 : "MDAS_TD_RSRC_TYP_UPDATE_ERROR",
    1057  -3807 : "MDAS_TD_USER_TYP_UPDATE_ERROR",
    1058  -3808 : "MDAS_TD_EXEC_TYP_UPDATE_ERROR",
    1059  -3809 : "MDAS_TD_LOCN_UPDATE_ERROR",
    1060  -3810 : "MDAS_TD_RSRC_FUNC_UPDATE_ERROR",
    1061  -3811 : "MDAS_TD_DS_FLDTYP_UPDATE_ERROR",
    1062  -3812 : "MDAS_TD_DS_SCHM_UPDATE_ERROR",
    1063  -3813 : "MDAS_TD_DS_SCHMDSC_UPDATE_ERROR",
    1064  -3814 : "MDAS_TD_SPEC_SUMM_UPDATE_ERROR",
    1065  -3815 : "MDAS_TD_ACTN_UPDATE_ERROR",
    1066  -3816 : "MDAS_TD_TCKT_UPDATE_ERROR",
    1067  -3817 : "MDAS_TD_AUTH_UPDATE_ERROR",
    1068  -3818 : "MDAS_TD_VERI_UPDATE_ERROR",
    1069  -3819 : "MDAS_TD_ENCR_UPDATE_ERROR",
    1070  -3820 : "MDAS_TD_DECR_UPDATE_ERROR",
    1071  -3821 : "MDAS_TD_RSRC_ACCS_UPDATE_ERROR",
    1072  -3822 : "MDAS_TD_METH_ACCS_UPDATE_ERROR",
    1073  -3823 : "MDAS_TD_DS_ACCS_UPDATE_ERROR",
    1074  -3824 : "MDAS_CD_DATA_UPDATE_ERROR",
    1075  -3825 : "MDAS_CD_METH_UPDATE_ERROR",
    1076  -3826 : "MDAS_CD_RSRC_UPDATE_ERROR",
    1077  -3827 : "MDAS_CD_USER_UPDATE_ERROR",
    1078  -3828 : "MDAS_TD_REPL_TYP_UPDATE_ERROR",
    1079  -3829 : "MDAS_TD_DS_REPPLCY_UPDATE_ERROR",
    1080  -3830 : "MDAS_TD_DS_PRTPLCY_UPDATE_ERROR",
    1081  -3831 : "MDAS_TD_DS_TRIG_UPDATE_ERROR",
    1082  -3832 : "MDAS_TD_DS_AGGR_UPDATE_ERROR",
    1083  -3833 : "MDAS_TD_MTHREP_PLC_UPDATE_ERROR",
    1084  -3834 : "MDAS_TD_RSRREP_PLC_UPDATE_ERROR",
    1085  -3835 : "MDAS_AD_ALIAS_UPDATE_ERROR",
    1086  -3836 : "MDAS_AD_DOMN_UPDATE_ERROR",
    1087  -3837 : "MDAS_AD_AUTH_KEY_UPDATE_ERROR",
    1088  -3838 : "MDAS_AD_REPL_UPDATE_ERROR",
    1089  -3839 : "MDAS_AD_COMMENTS_UPDATE_ERROR",
    1090  -3840 : "MDAS_AD_LOCK_UPDATE_ERROR",
    1091  -3841 : "MDAS_AD_ACCS_UPDATE_ERROR",
    1092  -3842 : "MDAS_AD_PART_UPDATE_ERROR",
    1093  -3843 : "MDAS_AD_AGGR_UPDATE_ERROR",
    1094  -3844 : "MDAS_AD_SUMM_UPDATE_ERROR",
    1095  -3845 : "MDAS_AD_TRIG_UPDATE_ERROR",
    1096  -3846 : "MDAS_AD_AUDIT_UPDATE_ERROR",
    1097  -3847 : "MDAS_AD_LIN_DATA_UPDATE_ERROR",
    1098  -3848 : "MDAS_AD_LIN_METH_UPDATE_ERROR",
    1099  -3849 : "MDAS_AD_LIN_USER_UPDATE_ERROR",
    1100  -3850 : "MDAS_AD_LIN_PARM_UPDATE_ERROR",
    1101  -3851 : "MDAS_AD_LIN_RSRC_UPDATE_ERROR",
    1102  -3852 : "MDAS_AD_FON_DATA_UPDATE_ERROR",
    1103  -3853 : "MDAS_AD_SD_UPDATE_ERROR",
    1104  -3854 : "MDAS_AD_TYP_SD_UPDATE_ERROR",
    1105  -3855 : "MDAS_AM_ALIAS_UPDATE_ERROR",
    1106  -3856 : "MDAS_AM_DOMN_UPDATE_ERROR",
    1107  -3857 : "MDAS_AM_AUTH_KEY_UPDATE_ERROR",
    1108  -3858 : "MDAS_AM_DECR_KEY_UPDATE_ERROR",
    1109  -3859 : "MDAS_AM_REPL_UPDATE_ERROR",
    1110  -3860 : "MDAS_AM_COMMENTS_UPDATE_ERROR",
    1111  -3861 : "MDAS_AM_LOCK_UPDATE_ERROR",
    1112  -3862 : "MDAS_AM_ACCS_UPDATE_ERROR",
    1113  -3863 : "MDAS_AM_SUMM_UPDATE_ERROR",
    1114  -3864 : "MDAS_AM_AUDIT_UPDATE_ERROR",
    1115  -3865 : "MDAS_AM_LIN_METH_UPDATE_ERROR",
    1116  -3866 : "MDAS_AM_LIN_DATA_UPDATE_ERROR",
    1117  -3867 : "MDAS_AM_LIN_USER_UPDATE_ERROR",
    1118  -3868 : "MDAS_AM_LIN_PARM_UPDATE_ERROR",
    1119  -3869 : "MDAS_AM_LIN_RSRC_UPDATE_ERROR",
    1120  -3870 : "MDAS_AM_CNVT_MTHID_UPDATE_ERROR",
    1121  -3871 : "MDAS_AM_CNVT_MTHTY_UPDATE_ERROR",
    1122  -3872 : "MDAS_AM_APPL_PARM_UPDATE_ERROR",
    1123  -3873 : "MDAS_AM_APPL_OUT_UPDATE_ERROR",
    1124  -3874 : "MDAS_AM_APPL_IN_UPDATE_ERROR",
    1125  -3875 : "MDAS_AM_APPL_RQR_UPDATE_ERROR",
    1126  -3876 : "MDAS_AM_APPL_PRED_UPDATE_ERROR",
    1127  -3877 : "MDAS_AM_COMP_MAP_UPDATE_ERROR",
    1128  -3878 : "MDAS_AM_COMP_MAPDS_UPDATE_ERROR",
    1129  -3879 : "MDAS_AM_COMP_MAPPR_UPDATE_ERROR",
    1130  -3880 : "MDAS_AM_SD_UPDATE_ERROR",
    1131  -3881 : "MDAS_AM_TYP_SD_UPDATE_ERROR",
    1132  -3882 : "MDAS_AR_ALIAS_UPDATE_ERROR",
    1133  -3883 : "MDAS_AR_DOMN_UPDATE_ERROR",
    1134  -3884 : "MDAS_AR_AUTH_KEY_UPDATE_ERROR",
    1135  -3885 : "MDAS_AR_DECR_KEY_UPDATE_ERROR",
    1136  -3886 : "MDAS_AR_REPL_UPDATE_ERROR",
    1137  -3887 : "MDAS_AR_COMMENTS_UPDATE_ERROR",
    1138  -3888 : "MDAS_AR_LOCK_UPDATE_ERROR",
    1139  -3889 : "MDAS_AR_ACCS_UPDATE_ERROR",
    1140  -3890 : "MDAS_AR_SUMM_UPDATE_ERROR",
    1141  -3891 : "MDAS_AR_AUDIT_UPDATE_ERROR",
    1142  -3892 : "MDAS_AR_LIN_RSRC_UPDATE_ERROR",
    1143  -3893 : "MDAS_AR_LIN_METH_UPDATE_ERROR",
    1144  -3894 : "MDAS_AR_LIN_USER_UPDATE_ERROR",
    1145  -3895 : "MDAS_AR_LIN_PARM_UPDATE_ERROR",
    1146  -3896 : "MDAS_AR_LIN_DATA_UPDATE_ERROR",
    1147  -3897 : "MDAS_AR_FON_RSRC_UPDATE_ERROR",
    1148  -3898 : "MDAS_AR_APPL_PRED_UPDATE_ERROR",
    1149  -3899 : "MDAS_AR_SD_UPDATE_ERROR",
    1150  -3900 : "MDAS_AR_TYP_SD_UPDATE_ERROR",
    1151  -3901 : "MDAS_AU_INFO_UPDATE_ERROR",
    1152  -3902 : "MDAS_AU_ALIAS_UPDATE_ERROR",
    1153  -3903 : "MDAS_AU_GROUP_UPDATE_ERROR",
    1154  -3904 : "MDAS_AU_DOMN_UPDATE_ERROR",
    1155  -3905 : "MDAS_AU_AUTH_KEY_UPDATE_ERROR",
    1156  -3906 : "MDAS_AU_DECR_KEY_UPDATE_ERROR",
    1157  -3907 : "MDAS_AU_SUMM_UPDATE_ERROR",
    1158  -3908 : "MDAS_AU_AUDIT_UPDATE_ERROR",
    1159  -3909 : "MDAS_AU_SD_UPDATE_ERROR",
    1160  -3910 : "MDAS_AU_TYP_SD_UPDATE_ERROR",
    1161  -3911 : "MDAS_COUNTER_UPDATE_ERROR",
    1162  -3912 : "MDAS_SD_KEYWORD_UPDATE_ERROR",
    1163  -3913 : "MDAS_TD_DATA_ACCS_UPDATE_ERROR",
    1164  -3914 : "MDAS_AD_ACCESS_UPDATE_ERROR",
    1165  -3915 : "MDAS_AD_GRP_ACCS_UPDATE_ERROR",
    1166  -3916 : "MDAS_AR_PHYSICAL_UPDATE_ERROR",
    1167  -3917 : "MDAS_AU_TCKT_DATA_UPDATE_ERROR",
    1168  -3918 : "MDAS_AU_TCKT_GRP_UPDATE_ERROR",
    1169  -3919 : "MDAS_AR_DB_RSRC_UPDATE_ERROR",
    1170  -3920 : "MDAS_TD_CONTAINER_UPDATE_ERROR",
    1171  -3921 : "MDAS_TD_RSRC_CLASS_UPDATE_ERROR",
    1172  -3922 : "MDAS_AU_AUTH_MAP_UPDATE_ERROR",
    1173  -3923 : "MDAS_AR_AUTH_UPDATE_ERROR",
    1174  -3924 : "MDAS_TD_AUTH_SCHM_UPDATE_ERROR",
    1175  -3925 : "MDAS_AD_ANNOTATION_UPDATE_ERROR",
    1176  -3926 : "MDAS_AD_CLASS_UPDATE_ERROR",
    1177  -3927 : "MDAS_AD_DATA_INDEX_UPDATE_ERROR",
    1178  -3928 : "MDAS_AD_DTYP_INDEX_UPDATE_ERROR",
    1179  -3929 : "MDAS_AD_COLL_INDEX_UPDATE_ERROR",
    1180  -3930 : "MDAS_AD_DATA_METH_UPDATE_ERROR",
    1181  -3931 : "MDAS_AD_DTYP_METH_UPDATE_ERROR",
    1182  -3932 : "MDAS_AD_COLL_METH_UPDATE_ERROR",
    1183  -3933 : "MDAS_AD_STRCT_BLOB_UPDATE_ERROR",
    1184  -3934 : "MDAS_AD_MDATA_UPDATE_ERROR",
    1185  -3935 : "MDAS_AD_COLLCONT_UPDATE_ERROR",
    1186  -3936 : "MDAS_AD_COLLMDATA_UPDATE_ERROR",
    1187  -3937 : "MDAS_AC_ANNOTATION_UPDATE_ERROR",
    1188  -3938 : "MDAS_AR_CMPND_RSRC_UPDATE_ERROR",
    1189  -3939 : "MDAS_AD_COMPOUND_UPDATE_ERROR",
    1190  -3940 : "MDAS_AR_TAPE_INFO_UPDATE_ERROR",
    1191  -3941 : "MDAS_AD_MISC1_UPDATE_ERROR",
    1192  -3942 : "MDAS_AU_MDATA_UPDATE_ERROR",
    1193  -3943 : "MDAS_AR_MDATA_UPDATE_ERROR",
    1194  -3944 : "MDAS_TD_ZONE_UPDATE_ERROR",
    1195  -3945 : "MDAS_AD_GUID_UPDATE_ERROR",
    1196  -3946 : "MDAS_AR_INFO_UPDATE_ERROR",
    1197  -3947 : "MDAS_AR_DAILY_TOT_UPDATE_ERROR",
    1198  -3948 : "MDAS_AR_USE_QUOTA_UPDATE_ERROR",
    1199  -4001 : "MDAS_TD_LOCK_ACCESS_ERROR",
    1200  -4002 : "MDAS_TD_DOMN_ACCESS_ERROR",
    1201  -4003 : "MDAS_TD_DATA_GRP_ACCESS_ERROR",
    1202  -4004 : "MDAS_TD_DATA_TYP_ACCESS_ERROR",
    1203  -4005 : "MDAS_TD_METH_TYP_ACCESS_ERROR",
    1204  -4006 : "MDAS_TD_RSRC_TYP_ACCESS_ERROR",
    1205  -4007 : "MDAS_TD_USER_TYP_ACCESS_ERROR",
    1206  -4008 : "MDAS_TD_EXEC_TYP_ACCESS_ERROR",
    1207  -4009 : "MDAS_TD_LOCN_ACCESS_ERROR",
    1208  -4010 : "MDAS_TD_RSRC_FUNC_ACCESS_ERROR",
    1209  -4011 : "MDAS_TD_DS_FLDTYP_ACCESS_ERROR",
    1210  -4012 : "MDAS_TD_DS_SCHM_ACCESS_ERROR",
    1211  -4013 : "MDAS_TD_DS_SCHMDSC_ACCESS_ERROR",
    1212  -4014 : "MDAS_TD_SPEC_SUMM_ACCESS_ERROR",
    1213  -4015 : "MDAS_TD_ACTN_ACCESS_ERROR",
    1214  -4016 : "MDAS_TD_TCKT_ACCESS_ERROR",
    1215  -4017 : "MDAS_TD_AUTH_ACCESS_ERROR",
    1216  -4018 : "MDAS_TD_VERI_ACCESS_ERROR",
    1217  -4019 : "MDAS_TD_ENCR_ACCESS_ERROR",
    1218  -4020 : "MDAS_TD_DECR_ACCESS_ERROR",
    1219  -4021 : "MDAS_TD_RSRC_ACCS_ACCESS_ERROR",
    1220  -4022 : "MDAS_TD_METH_ACCS_ACCESS_ERROR",
    1221  -4023 : "MDAS_TD_DS_ACCS_ACCESS_ERROR",
    1222  -4024 : "MDAS_CD_DATA_ACCESS_ERROR",
    1223  -4025 : "MDAS_CD_METH_ACCESS_ERROR",
    1224  -4026 : "MDAS_CD_RSRC_ACCESS_ERROR",
    1225  -4027 : "MDAS_CD_USER_ACCESS_ERROR",
    1226  -4028 : "MDAS_TD_REPL_TYP_ACCESS_ERROR",
    1227  -4029 : "MDAS_TD_DS_REPPLCY_ACCESS_ERROR",
    1228  -4030 : "MDAS_TD_DS_PRTPLCY_ACCESS_ERROR",
    1229  -4031 : "MDAS_TD_DS_TRIG_ACCESS_ERROR",
    1230  -4032 : "MDAS_TD_DS_AGGR_ACCESS_ERROR",
    1231  -4033 : "MDAS_TD_MTHREP_PLC_ACCESS_ERROR",
    1232  -4034 : "MDAS_TD_RSRREP_PLC_ACCESS_ERROR",
    1233  -4035 : "MDAS_AD_ALIAS_ACCESS_ERROR",
    1234  -4036 : "MDAS_AD_DOMN_ACCESS_ERROR",
    1235  -4037 : "MDAS_AD_AUTH_KEY_ACCESS_ERROR",
    1236  -4038 : "MDAS_AD_REPL_ACCESS_ERROR",
    1237  -4039 : "MDAS_AD_COMMENTS_ACCESS_ERROR",
    1238  -4040 : "MDAS_AD_LOCK_ACCESS_ERROR",
    1239  -4041 : "MDAS_AD_ACCS_ACCESS_ERROR",
    1240  -4042 : "MDAS_AD_PART_ACCESS_ERROR",
    1241  -4043 : "MDAS_AD_AGGR_ACCESS_ERROR",
    1242  -4044 : "MDAS_AD_SUMM_ACCESS_ERROR",
    1243  -4045 : "MDAS_AD_TRIG_ACCESS_ERROR",
    1244  -4046 : "MDAS_AD_AUDIT_ACCESS_ERROR",
    1245  -4047 : "MDAS_AD_LIN_DATA_ACCESS_ERROR",
    1246  -4048 : "MDAS_AD_LIN_METH_ACCESS_ERROR",
    1247  -4049 : "MDAS_AD_LIN_USER_ACCESS_ERROR",
    1248  -4050 : "MDAS_AD_LIN_PARM_ACCESS_ERROR",
    1249  -4051 : "MDAS_AD_LIN_RSRC_ACCESS_ERROR",
    1250  -4052 : "MDAS_AD_FON_DATA_ACCESS_ERROR",
    1251  -4053 : "MDAS_AD_SD_ACCESS_ERROR",
    1252  -4054 : "MDAS_AD_TYP_SD_ACCESS_ERROR",
    1253  -4055 : "MDAS_AM_ALIAS_ACCESS_ERROR",
    1254  -4056 : "MDAS_AM_DOMN_ACCESS_ERROR",
    1255  -4057 : "MDAS_AM_AUTH_KEY_ACCESS_ERROR",
    1256  -4058 : "MDAS_AM_DECR_KEY_ACCESS_ERROR",
    1257  -4059 : "MDAS_AM_REPL_ACCESS_ERROR",
    1258  -4060 : "MDAS_AM_COMMENTS_ACCESS_ERROR",
    1259  -4061 : "MDAS_AM_LOCK_ACCESS_ERROR",
    1260  -4062 : "MDAS_AM_ACCS_ACCESS_ERROR",
    1261  -4063 : "MDAS_AM_SUMM_ACCESS_ERROR",
    1262  -4064 : "MDAS_AM_AUDIT_ACCESS_ERROR",
    1263  -4065 : "MDAS_AM_LIN_METH_ACCESS_ERROR",
    1264  -4066 : "MDAS_AM_LIN_DATA_ACCESS_ERROR",
    1265  -4067 : "MDAS_AM_LIN_USER_ACCESS_ERROR",
    1266  -4068 : "MDAS_AM_LIN_PARM_ACCESS_ERROR",
    1267  -4069 : "MDAS_AM_LIN_RSRC_ACCESS_ERROR",
    1268  -4070 : "MDAS_AM_CNVT_MTHID_ACCESS_ERROR",
    1269  -4071 : "MDAS_AM_CNVT_MTHTY_ACCESS_ERROR",
    1270  -4072 : "MDAS_AM_APPL_PARM_ACCESS_ERROR",
    1271  -4073 : "MDAS_AM_APPL_OUT_ACCESS_ERROR",
    1272  -4074 : "MDAS_AM_APPL_IN_ACCESS_ERROR",
    1273  -4075 : "MDAS_AM_APPL_RQR_ACCESS_ERROR",
    1274  -4076 : "MDAS_AM_APPL_PRED_ACCESS_ERROR",
    1275  -4077 : "MDAS_AM_COMP_MAP_ACCESS_ERROR",
    1276  -4078 : "MDAS_AM_COMP_MAPDS_ACCESS_ERROR",
    1277  -4079 : "MDAS_AM_COMP_MAPPR_ACCESS_ERROR",
    1278  -4080 : "MDAS_AM_SD_ACCESS_ERROR",
    1279  -4081 : "MDAS_AM_TYP_SD_ACCESS_ERROR",
    1280  -4082 : "MDAS_AR_ALIAS_ACCESS_ERROR",
    1281  -4083 : "MDAS_AR_DOMN_ACCESS_ERROR",
    1282  -4084 : "MDAS_AR_AUTH_KEY_ACCESS_ERROR",
    1283  -4085 : "MDAS_AR_DECR_KEY_ACCESS_ERROR",
    1284  -4086 : "MDAS_AR_REPL_ACCESS_ERROR",
    1285  -4087 : "MDAS_AR_COMMENTS_ACCESS_ERROR",
    1286  -4088 : "MDAS_AR_LOCK_ACCESS_ERROR",
    1287  -4089 : "MDAS_AR_ACCS_ACCESS_ERROR",
    1288  -4090 : "MDAS_AR_SUMM_ACCESS_ERROR",
    1289  -4091 : "MDAS_AR_AUDIT_ACCESS_ERROR",
    1290  -4092 : "MDAS_AR_LIN_RSRC_ACCESS_ERROR",
    1291  -4093 : "MDAS_AR_LIN_METH_ACCESS_ERROR",
    1292  -4094 : "MDAS_AR_LIN_USER_ACCESS_ERROR",
    1293  -4095 : "MDAS_AR_LIN_PARM_ACCESS_ERROR",
    1294  -4096 : "MDAS_AR_LIN_DATA_ACCESS_ERROR",
    1295  -4097 : "MDAS_AR_FON_RSRC_ACCESS_ERROR",
    1296  -4098 : "MDAS_AR_APPL_PRED_ACCESS_ERROR",
    1297  -4099 : "MDAS_AR_SD_ACCESS_ERROR",
    1298  -4100 : "MDAS_AR_TYP_SD_ACCESS_ERROR",
    1299  -4101 : "MDAS_AU_INFO_ACCESS_ERROR",
    1300  -4102 : "MDAS_AU_ALIAS_ACCESS_ERROR",
    1301  -4103 : "MDAS_AU_GROUP_ACCESS_ERROR",
    1302  -4104 : "MDAS_AU_DOMN_ACCESS_ERROR",
    1303  -4105 : "MDAS_AU_AUTH_KEY_ACCESS_ERROR",
    1304  -4106 : "MDAS_AU_DECR_KEY_ACCESS_ERROR",
    1305  -4107 : "MDAS_AU_SUMM_ACCESS_ERROR",
    1306  -4108 : "MDAS_AU_AUDIT_ACCESS_ERROR",
    1307  -4109 : "MDAS_AU_SD_ACCESS_ERROR",
    1308  -4110 : "MDAS_AU_TYP_SD_ACCESS_ERROR",
    1309  -4111 : "MDAS_COUNTER_ACCESS_ERROR",
    1310  -4112 : "MDAS_SD_KEYWORD_ACCESS_ERROR",
    1311  -4113 : "MDAS_TD_DATA_ACCS_ACCESS_ERROR",
    1312  -4114 : "MDAS_AD_ACCESS_ACCESS_ERROR",
    1313  -4115 : "MDAS_AD_GRP_ACCS_ACCESS_ERROR",
    1314  -4116 : "MDAS_AR_PHYSICAL_ACCESS_ERROR",
    1315  -4117 : "MDAS_AU_TCKT_DATA_ACCESS_ERROR",
    1316  -4118 : "MDAS_AU_TCKT_GRP_ACCESS_ERROR",
    1317  -4119 : "MDAS_AR_DB_RSRC_ACCESS_ERROR",
    1318  -4120 : "MDAS_TD_CONTAINER_ACCESS_ERROR",
    1319  -4121 : "MDAS_TD_RSRC_CLASS_ACCESS_ERROR",
    1320  -4122 : "MDAS_AU_AUTH_MAP_ACCESS_ERROR",
    1321  -4123 : "MDAS_AR_AUTH_ACCESS_ERROR",
    1322  -4124 : "MDAS_TD_AUTH_SCHM_ACCESS_ERROR",
    1323  -4125 : "MDAS_AD_ANNOTATION_ACCESS_ERROR",
    1324  -4126 : "MDAS_AD_CLASS_ACCESS_ERROR",
    1325  -4127 : "MDAS_AD_DATA_INDEX_ACCESS_ERROR",
    1326  -4128 : "MDAS_AD_DTYP_INDEX_ACCESS_ERROR",
    1327  -4129 : "MDAS_AD_COLL_INDEX_ACCESS_ERROR",
    1328  -4130 : "MDAS_AD_DATA_METH_ACCESS_ERROR",
    1329  -4131 : "MDAS_AD_DTYP_METH_ACCESS_ERROR",
    1330  -4132 : "MDAS_AD_COLL_METH_ACCESS_ERROR",
    1331  -4133 : "MDAS_AD_STRCT_BLOB_ACCESS_ERROR",
    1332  -4134 : "MDAS_AD_MDATA_ACCESS_ERROR",
    1333  -4135 : "MDAS_AD_COLLCONT_ACCESS_ERROR",
    1334  -4136 : "MDAS_AD_COLLMDATA_ACCESS_ERROR",
    1335  -4137 : "MDAS_AC_ANNOTATION_ACCESS_ERROR",
    1336  -4138 : "MDAS_AR_CMPND_RSRC_ACCESS_ERROR",
    1337  -4139 : "MDAS_AD_COMPOUND_ACCESS_ERROR",
    1338  -4140 : "MDAS_AR_TAPE_INFO_ACCESS_ERROR",
    1339  -4141 : "MDAS_AD_MISC1_ACCESS_ERROR",
    1340  -4142 : "MDAS_AU_MDATA_ACCESS_ERROR",
    1341  -4143 : "MDAS_AR_MDATA_ACCESS_ERROR",
    1342  -4144 : "MDAS_TD_ZONE_ACCESS_ERROR",
    1343  -4145 : "MDAS_AD_GUID_ACCESS_ERROR",
    1344  -4146 : "MDAS_AR_INFO_ACCESS_ERROR",
    1345  -4147 : "MDAS_AR_DAILY_TOT_ACCESS_ERROR",
    1346  -4148 : "MDAS_AR_USE_QUOTA_ACCESS_ERROR",
    1347  -4501 : "ORA_AUTOCOMMIT_TURNOFF_ERROR",
    1348  -4502 : "ORA_CONNECT_ERROR",
    1349  -4503 : "ORA_TRANSACT_CLOSE_ERROR",
    1350  -4504 : "ORA_DISCONNECT_ERROR",
    1351  -4505 : "ORA_CURSOR_OPEN_ERROR",
    1352  -4506 : "ORA_PARSE_ERROR",
    1353  -4507 : "ORA_EXEC_ERROR",
    1354  -4508 : "ORA_SELECT_DESCRIBE_ERROR",
    1355  -4509 : "ORA_FETCH_ERROR",
    1356  -4510 : "ORA_NO_DATA_FOUND",
    1357  -4511 : "ORA_DATA_LINK_CREATION_ERROR",
    1358  -5000 : "TAPLIB_MNT_CART_ERROR",
    1359  -5001 : "TAPLIB_INTERNAL_ERROR",
    1360  -5002 : "TAPLIB_INX_ERROR",
    1361  -5003 : "TAPLIB_NO_TAPE_RESC",
    1362  -5004 : "TAPLIB_NO_BLANK_TAPE",
    1363  -5005 : "TAPLIB_SET_ACCESS_FAILED",
    1364  -5006 : "TAPLIB_CART_TYPE_NOT_EXIST",
    1365  -5007 : "TAPLIB_CART_LOC_ERROR",
    1366  -5008 : "TAPLIB_CART_MISMATCH_FOR_OPR",
    1367  -5200 : "TAPE_NUM_ERROR",
    1368  -5201 : "TAPE_FILE_SEG_NUM_ERROR",
    1369  -5202 : "TAPE_FILE_SEQ_NUM_ERROR",
    1370  -5203 : "TAPE_FILE_NOT_OPENED",
    1371  -5204 : "TAPE_BLOCK_SZ_ERROR",
    1372  -5205 : "TAPE_VOL_LABEL_ERROR",
    1373  -5206 : "TAPE_HEADER_LABEL_ERROR",
    1374  -5207 : "TAPE_FILE_POSITION_ERROR",
    1375  -5208 : "TAPE_DEVICE_PATH_ERROR",
    1376  -5209 : "TAPE_TAPELIB_CONFIG_ERROR",
    1377  -5210 : "TAPE_DEVICE_INX_ERROR",
    1378  -5211 : "Internal tape config error",
    1379  -5212 : "TAPE_OUT_OF_BLANK_TAPE",
    1380  -5400 :                 "ADS_UNKNOWN_ERROR",
    1381  -5401 :      "ADS_ERROR_FUNC_NOT_SUPPORTED",
    1382  -5402 : "ADS_ERROR_EXECUTING_PIPED_COMMAND0",
    1383  -5403 :             "ADS_ERROR_IN_PATHTAPE ",
    1384  -5404 :        "ADS_ERROR_IN_FLFSYS_CREATE ",
    1385  -5405 :       "ADS_ERROR_IN_FLFSYS_DESTROY ",
    1386  -5406 : "ADS_ERROR_EXECUTING_PIPED_COMMAND",
    1387  -5407 :                 "ADS_ERROR_ON_OPEN",
    1388  -5408 :                "ADS_ERROR_ON_CLOSE",
    1389  -5409 :             "ADS_ERROR_IN_VTP_OPEN",
    1390  -5410 :            "ADS_ERROR_IN_VTP_CLOSE",
    1391  -5411 :     "ADS_ERROR_WRITING_TAPE_LABELS",
    1392  -5412 :     "ADS_ERROR_READING_TAPE_LABELS",
    1393  -5413 :            "ADS_ERROR_IN_TAPE_READ",
    1394  -5414 :           "ADS_ERROR_IN_TAPE_WRITE",
    1395  -5415 :       "ADS_ERROR_ALLOCATING_MEMORY",
    1396  -6001 :       "GRIDFTP_OPEN_NULL_URL",
    1397  -6003 :       "GRIDFTP_CANNOT_CALLOC",
    1398  -6004 :       "GRIDFTP_CANNOT_FIND_NODE",
    1399  -6005 :       "GRIDFTP_GETHOSTNAME_FAILED",
    1400  -6006 :       "GRIDFTP_GETHOSTBYNAME_FAILED",
    1401  -6007 :       "GRIDFTP_NOT_A_WRITE_OPERATION",
    1402  -6008 :       "GRIDFTP_CLIENT_GET_ERROR",
    1403  -6009 :       "GRIDFTP_READ_DONE_CB_ERR",
    1404  -6010 :       "GRIDFTP_CLIENT_PUT_ERROR",
    1405  -6011 :       "GRIDFTP_WRITE_DONE_CB_ERR",
    1406  -6012 :       "GRIDFTP_CLIENT_MKDIR_ERROR",
    1407  -6013 :       "GRIDFTP_MKDIR_DONE_CB_ERR",
    1408  -6014 :       "GRIDFTP_CLIENT_RMDIR_ERROR",
    1409  -6015 :       "GRIDFTP_RMDIR_DONE_CB_ERR",
    1410  -6016 :       "GRIDFTP_CLIENT_UNLINK_ERROR",
    1411  -6017 :       "GRIDFTP_UNLINK_DONE_CB_ERR",
    1412  -6018 :       "GRIDFTP_CLIENT_EXISTS_ERROR",
    1413  -6019 :       "GRIDFTP_FILE_OR_DIR_EXISTS_DONE_CB_ERR",
    1414  -6020 :       "GRIDFTP_CLIENT_SIZE_ERROR",
    1415  -6021 :       "GRIDFTP_SIZE_DONE_CB_ERR",
    1416  -6022 :       "GRIDFTP_OPERATION_NOT_SUPPORT",
    1417  -6023 :       "GRIDFTP_NEED_NEW_PROXY_CERTIFICATE",
    1418  -6024 :       "GRIDFTP_NO_USER_CERT_ERR",
    1419  -6025 :       "GRIDFTP_NO_FREE_GFTP_CONN_ERR",
    1420  -6026 :       "GRIDFTP_GFTP_CONN_OUT_OF_RANG_ERR",
    1421  -6027 :       "GRIDFTP_BAD_INPUT_URL_ERR",
    1422  -999999 :       "DONT_SEND_RETURN",
    1423  -9999999 :       "EXIT_WHEN_DONE",
    1424  -99999999 :       "MSG_USE_SINGLE_PORT"}
    1425